
SET client_encoding = 'UNICODE';
SET check_function_bodies = false;

SET search_path = public, pg_catalog;


CREATE FUNCTION plpgsql_call_handler() RETURNS language_handler
    AS '$libdir/plpgsql', 'plpgsql_call_handler'
    LANGUAGE c;



CREATE TRUSTED PROCEDURAL LANGUAGE plpgsql HANDLER plpgsql_call_handler;



REVOKE ALL ON SCHEMA public FROM PUBLIC;
GRANT ALL ON SCHEMA public TO PUBLIC;



CREATE TABLE deleted_project (
    unix_group_name character varying(30) NOT NULL,
    delete_date timestamp with time zone DEFAULT now(),
    isdeleted boolean DEFAULT false
);



CREATE TABLE project (
    project_id serial NOT NULL,
    project_name character varying(40),
    unix_name character varying(30) NOT NULL,
    homepage_url text,
    is_public boolean DEFAULT true,
    status integer DEFAULT 0,
    description text,
    register_purpose text,
    register_license_other text,
    create_date timestamp with time zone DEFAULT now(),
    template_project_id integer,
    is_template boolean DEFAULT false
);



CREATE TABLE country_code (
    country_name character varying(80),
    ccode character(2) NOT NULL
);



CREATE TABLE theme (
    theme_id serial NOT NULL,
    dirname text NOT NULL,
    fullname text NOT NULL
);



CREATE TABLE "language" (
    language_id serial NOT NULL,
    name text NOT NULL,
    filename text NOT NULL,
    language_code character(5)
);



CREATE TABLE "user" (
    user_id serial NOT NULL,
    unix_name text NOT NULL,
    email text NOT NULL,
    status integer DEFAULT 0,
    password_md5 character varying(32) NOT NULL,
    password_crypt character varying(40) NOT NULL,
    create_date timestamp with time zone DEFAULT now() NOT NULL,
    confirm_hash character varying(32),
    email_new text,
    timezone text,
    date_format text,
    address text,
    address2 text,
    phone text,
    fax text,
    title text,
    firstname text,
    lastname text,
    ccode character(2) NOT NULL,
    language_id integer NOT NULL,
    theme_id integer NOT NULL
);



CREATE TABLE site_admin (
    user_id integer NOT NULL
);



CREATE TABLE filesystem (
    filesystem_id serial NOT NULL,
    section character varying(20),
    ref_id integer,
    file_name text,
    file_name_safe text,
    file_type text,
    file_size integer,
    deleted boolean,
    posted_by integer NOT NULL,
    download_count integer DEFAULT 0,
    strings text
);



CREATE TABLE stats_project_page_view (
    project_id integer NOT NULL,
    count_date date NOT NULL,
    count_views integer NOT NULL
);



CREATE TABLE stats_site_page_view (
    count_date date NOT NULL,
    count_views integer NOT NULL
);



CREATE TABLE monitor (
    section character varying(20) NOT NULL,
    ref_id integer DEFAULT 0 NOT NULL,
    user_id integer NOT NULL
);



CREATE TABLE audit_trail (
    audit_trail_id serial NOT NULL,
    change_date timestamp with time zone DEFAULT now(),
    user_id integer NOT NULL,
    section character varying(20),
    ref_id integer DEFAULT 0,
    field_name character varying(20),
    new_value text,
    old_value text
);



CREATE TABLE unix_shell (
    unix_shell_id serial NOT NULL,
    shell_name text,
    "path" text
);



CREATE TABLE user_unix (
    user_id integer NOT NULL,
    unix_shell_id integer NOT NULL,
    unix_uid integer DEFAULT 0 NOT NULL,
    unix_gid integer DEFAULT 0,
    unix_box character varying(10) DEFAULT 'shell1'::character varying NOT NULL,
    authorized_keys text
);



CREATE TABLE scm_server (
    scm_server_id serial NOT NULL,
    scm_type text,
    hostname text
);



CREATE TABLE docman_folder (
    docman_folder_id serial NOT NULL,
    project_id integer NOT NULL,
    folder_name text,
    is_public boolean DEFAULT true,
    parent_folder_id integer DEFAULT 0,
    doc_count integer DEFAULT 0
);



CREATE TABLE project_scm (
    project_id integer NOT NULL,
    enable_anonread boolean DEFAULT true,
    scm_server_id integer NOT NULL,
    controlled boolean DEFAULT true,
    hostname text,
    root_directory text
);



CREATE TABLE forum (
    forum_id serial NOT NULL,
    section character varying(20) NOT NULL,
    ref_id integer NOT NULL,
    forum_name text NOT NULL,
    is_public boolean DEFAULT true,
    description text,
    send_all_posts_to text,
    thread_count integer DEFAULT 0,
    message_count integer DEFAULT 0,
    most_recent_date timestamp with time zone DEFAULT now(),
    moderation_level integer DEFAULT 0
);



CREATE TABLE forum_thread (
    forum_thread_id serial NOT NULL,
    forum_id integer NOT NULL,
    created_by integer NOT NULL,
    thread_name text,
    message_count integer DEFAULT 0,
    most_recent_date timestamp with time zone DEFAULT now()
);



CREATE TABLE forum_message (
    forum_message_id serial NOT NULL,
    forum_thread_id integer NOT NULL,
    created_by integer NOT NULL,
    subject text NOT NULL,
    body text NOT NULL,
    post_date timestamp with time zone DEFAULT now(),
    parent_forum_message_id integer DEFAULT 0,
    mail_msg_id text,
    mail_sender text,
    is_approved boolean DEFAULT true
);



CREATE TABLE user_blog (
    user_blog_id serial NOT NULL,
    user_id integer NOT NULL,
    subject text NOT NULL,
    content text NOT NULL,
    post_date timestamp with time zone DEFAULT now() NOT NULL
);



CREATE TABLE frs_package (
    frs_package_id serial NOT NULL,
    project_id integer NOT NULL,
    package_name text,
    status_id integer DEFAULT 1,
    is_public boolean DEFAULT true,
    require_login boolean DEFAULT false
);



CREATE TABLE frs_release (
    frs_release_id serial NOT NULL,
    frs_package_id integer NOT NULL,
    release_name text,
    release_notes text,
    changes text,
    status_id integer DEFAULT 1,
    preformatted boolean DEFAULT false,
    release_date timestamp with time zone DEFAULT now(),
    released_by integer NOT NULL
);



CREATE TABLE filesystem_download (
    ip_address text,
    filesystem_id integer,
    download_date timestamp with time zone DEFAULT now(),
    user_id integer
);



CREATE TABLE deleted_mailing_list (
    mailing_list_name character varying(30) NOT NULL,
    delete_date timestamp with time zone DEFAULT now(),
    isdeleted boolean DEFAULT false
);



CREATE TABLE mailman (
    mailman_id serial NOT NULL,
    project_id integer NOT NULL,
    list_name text,
    is_public boolean DEFAULT true,
    list_password character varying(16),
    created_by integer NOT NULL,
    status integer DEFAULT 1,
    list_description text,
    create_date timestamp with time zone DEFAULT now()
);



CREATE TABLE news (
    news_id serial NOT NULL,
    project_id integer NOT NULL,
    submitted_by integer NOT NULL,
    is_approved boolean DEFAULT true,
    post_date timestamp with time zone DEFAULT now(),
    summary text,
    details text
);



CREATE TABLE news_count (
    project_id integer NOT NULL,
    total integer DEFAULT 0
);



CREATE FUNCTION news_insert_agg() RETURNS "trigger"
    AS '
BEGIN
        INSERT INTO news_count (project_id,total) 
                VALUES (NEW.project_id,0);
        RETURN NEW;
END;    
'
    LANGUAGE plpgsql;



CREATE TABLE user_session (
    user_id integer NOT NULL,
    session_hash character(32) NOT NULL,
    ip_addr character(15) NOT NULL,
    login_time timestamp with time zone DEFAULT now()
);



CREATE TABLE snippet (
    snippet_id serial NOT NULL,
    section character varying(20) NOT NULL,
    ref_id integer NOT NULL,
    created_by integer NOT NULL,
    create_date timestamp with time zone DEFAULT now(),
    snippet_name text,
    snippet_description text
);



CREATE TABLE survey_question (
    survey_question_id serial NOT NULL,
    project_id integer NOT NULL,
    question text NOT NULL,
    question_type integer NOT NULL
);



CREATE TABLE survey (
    survey_id serial NOT NULL,
    project_id integer NOT NULL,
    survey_title text NOT NULL,
    survey_questions text NOT NULL,
    is_active boolean DEFAULT true
);



CREATE TABLE survey_response (
    user_id integer NOT NULL,
    survey_id integer DEFAULT 0 NOT NULL,
    question_id integer DEFAULT 0 NOT NULL,
    response text NOT NULL,
    post_date timestamp with time zone DEFAULT now() NOT NULL
);



CREATE TABLE trove_category (
    trove_category_id serial NOT NULL,
    root_trove_category_id integer NOT NULL,
    parent_trove_category_id integer NOT NULL,
    alias text NOT NULL,
    category_name text NOT NULL,
    description text NOT NULL
);



CREATE TABLE trove_link (
    section character varying(20) NOT NULL,
    ref_id integer NOT NULL,
    trove_category_id integer NOT NULL
);



CREATE TABLE role (
    role_id serial NOT NULL,
    project_id integer NOT NULL,
    role_name text NOT NULL
);



CREATE TABLE role_setting (
    role_id integer NOT NULL,
    section character varying(20) NOT NULL,
    ref_id integer NOT NULL,
    value character varying(2) NOT NULL
);



CREATE TABLE user_project (
    user_id integer NOT NULL,
    project_id integer NOT NULL,
    role_id integer DEFAULT 1,
    join_date timestamp with time zone DEFAULT now()
);



CREATE TABLE user_preference (
    user_id integer NOT NULL,
    preference_name character varying(20) NOT NULL,
    set_date timestamp with time zone DEFAULT now(),
    preference_value text
);



CREATE TABLE tracker (
    tracker_id serial NOT NULL,
    project_id integer NOT NULL,
    tracker_name text,
    description text,
    is_public boolean DEFAULT true,
    restrict_browse boolean DEFAULT true,
    email_all_updates boolean DEFAULT false,
    email_address text,
    due_period integer DEFAULT 2592000,
    submit_instructions text,
    browse_instructions text,
    datatype integer,
    item_total integer DEFAULT 0,
    open_count integer DEFAULT 0
);



CREATE TABLE tracker_item (
    tracker_item_id serial NOT NULL,
    tracker_id integer NOT NULL,
    status_id integer DEFAULT 1,
    priority integer DEFAULT 3,
    submitted_by integer NOT NULL,
    open_date timestamp with time zone DEFAULT now(),
    close_date timestamp with time zone,
    summary text NOT NULL,
    details text NOT NULL,
    last_modified_date timestamp with time zone DEFAULT now(),
    last_modified_by integer DEFAULT 0,
    sort_order integer DEFAULT 0,
    parent_id integer DEFAULT 0
);



CREATE TABLE tracker_time_code (
    tracker_time_code_id serial NOT NULL,
    time_name text
);



CREATE TABLE tracker_item_time (
    tracker_item_time_id serial NOT NULL,
    date_entry date DEFAULT now() NOT NULL,
    user_id integer NOT NULL,
    tracker_item_id integer NOT NULL,
    hours double precision,
    tracker_time_code_id integer NOT NULL
);



CREATE TABLE tracker_item_relation (
    tracker_item_id integer NOT NULL,
    related_tracker_item_id integer NOT NULL,
    link_type character(2) DEFAULT 'FS'::bpchar
);



CREATE TABLE tracker_item_assignee (
    tracker_item_id integer NOT NULL,
    assignee integer NOT NULL,
    percent_utilization integer DEFAULT 100
);



CREATE TABLE tracker_item_message (
    tracker_item_message_id serial NOT NULL,
    tracker_item_id integer NOT NULL,
    submitted_by integer NOT NULL,
    adddate timestamp with time zone DEFAULT now(),
    body text NOT NULL
);



CREATE TABLE tracker_canned_response (
    tracker_canned_response_id serial NOT NULL,
    tracker_id integer NOT NULL,
    title text NOT NULL,
    body text NOT NULL
);



CREATE FUNCTION forum_insertdelete_agg() RETURNS "trigger"
    AS '
DECLARE
	forumrec record;
BEGIN
	IF TG_OP=''INSERT'' THEN
		FOR forumrec IN SELECT * FROM forum_thread WHERE forum_thread_id=NEW.forum_thread_id LOOP
			UPDATE forum SET message_count=message_count+1, most_recent_date=now()
				WHERE forum_id=forumrec.forum_id;
		END LOOP;
	ELSE
		FOR forumrec IN SELECT * FROM forum_thread WHERE forum_thread_id=OLD.forum_thread_id LOOP
			UPDATE forum SET message_count=message_count-1
				WHERE forum_id=forumrec.forum_id;
		END LOOP;
	END IF;
        RETURN NEW;
END;
'
    LANGUAGE plpgsql;



CREATE FUNCTION tracker_update_agg() RETURNS "trigger"
    AS '
BEGIN
	--
	-- see if they are moving to a new trackertype
	-- if so, its a more complex operation
	--
	IF NEW.tracker_id <> OLD.tracker_id THEN
		--
		-- transferred trackers always have a status of 1
		-- so we will increment the new trackertypes sums
		--
		IF OLD.status_id=0 THEN
			UPDATE tracker SET item_total=item_total-1 
				WHERE tracker_id=OLD.tracker_id;
		ELSE 
			IF OLD.status_id=1 THEN
				UPDATE tracker SET item_total=item_total-1,open_count=open_count-1 
					WHERE tracker_id=OLD.tracker_id;
			END IF;
		END IF;

		IF NEW.status_id=0 THEN
			UPDATE tracker SET item_total=item_total+1 
				WHERE tracker_id=NEW.tracker_id;
		ELSE
			IF NEW.status_id=1 THEN
				UPDATE tracker SET item_total=item_total+1, open_count=open_count+1 
					WHERE tracker_id=NEW.tracker_id;
			END IF;
		END IF;
	ELSE
		--
		-- just need to evaluate the status flag and 
		-- increment/decrement the counter as necessary
		--
		IF NEW.status_id <> OLD.status_id THEN
			IF NEW.status_id = 1 THEN
				IF OLD.status_id=0 THEN
					UPDATE tracker SET open_count=open_count+1 
						WHERE tracker_id=NEW.tracker_id;
				END IF;
			ELSE
				IF NEW.status_id = 0 THEN
					IF OLD.status_id=1 THEN
						UPDATE tracker SET open_count=open_count-1 
							WHERE tracker_id=NEW.tracker_id;
					END IF;
				END IF;
			END IF;
		END IF;	
	END IF;
	RETURN NEW;
END;
'
    LANGUAGE plpgsql;



CREATE TABLE notification_queue (
    notification_queue_id serial NOT NULL,
    section character varying(20),
    ref_id integer NOT NULL,
    user_id integer NOT NULL,
    subject text,
    body text,
    queue_date timestamp with time zone DEFAULT now(),
    send_date timestamp with time zone DEFAULT now()
);



CREATE TABLE scm_user_stats (
    stat_date date NOT NULL,
    project_id integer NOT NULL,
    user_id integer NOT NULL,
    checkouts integer NOT NULL,
    commits integer NOT NULL,
    adds integer NOT NULL
);



CREATE TABLE scm_project_stats (
    stat_date date NOT NULL,
    project_id integer NOT NULL,
    checkouts integer NOT NULL,
    commits integer NOT NULL,
    adds integer NOT NULL
);



CREATE TABLE activity_log (
    activity_date timestamp with time zone DEFAULT now() NOT NULL,
    project_id integer DEFAULT 0,
    page text,
    activity_type integer DEFAULT 0
);



CREATE TABLE plugin (
    plugin_id serial NOT NULL,
    plugin_name text NOT NULL,
    plugin_desc text NOT NULL,
    plugin_type text NOT NULL,
    plugin_order integer DEFAULT 0,
    exclusive_type text
);



CREATE TABLE plugin_dependency (
    plugin_id integer NOT NULL,
    dependson_plugin_id integer NOT NULL
);



CREATE TABLE project_plugin (
    project_id integer NOT NULL,
    plugin_id integer NOT NULL,
    plugin_order integer
);



CREATE TABLE user_plugin (
    user_id integer NOT NULL,
    plugin_id integer NOT NULL,
    plugin_order integer DEFAULT 0
);



CREATE TABLE user_relation (
    user_id integer NOT NULL,
    related_user_id integer NOT NULL
);



CREATE TABLE user_watched_project (
    user_id integer NOT NULL,
    project_id integer NOT NULL
);



CREATE TABLE cron_history (
    rundate timestamp with time zone DEFAULT now(),
    job text,
    output text
);



CREATE TABLE tracker_extra_field (
    tracker_extra_field_id serial NOT NULL,
    tracker_id integer NOT NULL,
    field_name text NOT NULL,
    field_type integer NOT NULL,
    attribute1 integer DEFAULT 0,
    attribute2 integer DEFAULT 0,
    is_required boolean DEFAULT false,
    alias text NOT NULL,
    field_order integer DEFAULT 0,
    use_in_quick_browse boolean DEFAULT false,
    show_on_submit boolean DEFAULT false
);



CREATE TABLE tracker_extra_field_element (
    element_id serial NOT NULL,
    tracker_extra_field_id integer NOT NULL,
    element_name text NOT NULL,
    status_id integer DEFAULT 1,
    default_selected boolean DEFAULT false,
    sort_order integer DEFAULT 0
);



CREATE TABLE tracker_extra_field_data (
    tracker_extra_field_data_id serial NOT NULL,
    tracker_item_id integer NOT NULL,
    field_data text,
    tracker_extra_field_id integer NOT NULL
);



CREATE TABLE project_join_request (
    project_id integer NOT NULL,
    user_id integer NOT NULL,
    comments text,
    request_date timestamp with time zone DEFAULT now()
);



CREATE FUNCTION update_last_modified_date() RETURNS "trigger"
    AS '
BEGIN
NEW.last_modified_date = NOW();
RETURN NEW;
END;
'
    LANGUAGE plpgsql;



CREATE TABLE scm_module (
    scm_module_id serial NOT NULL,
    project_id integer NOT NULL,
    "path" text
);



CREATE TABLE scm_preference (
    project_id integer NOT NULL,
    require_tracker_item_id boolean DEFAULT false NOT NULL
);



CREATE TABLE scm_commit (
    scm_commit_id serial NOT NULL,
    project_id integer NOT NULL,
    commit_date timestamp with time zone DEFAULT now(),
    message_log text,
    user_id integer NOT NULL
);



CREATE TABLE tracker_item_scm_commit (
    tracker_item_id integer NOT NULL,
    scm_commit_id integer NOT NULL
);



CREATE TABLE scm_commit_file (
    scm_commit_id integer NOT NULL,
    modified_file text NOT NULL,
    prev_version text,
    new_version text
);



CREATE TABLE tracker_query (
    tracker_query_id serial NOT NULL,
    tracker_id integer NOT NULL,
    user_id integer NOT NULL,
    query_name text NOT NULL,
    is_selected boolean DEFAULT false
);



CREATE TABLE tracker_query_field (
    tracker_query_id integer NOT NULL,
    query_field_type text NOT NULL,
    query_field_id integer NOT NULL,
    query_field_values text NOT NULL
);



CREATE TABLE wiki_page (
    wiki_page_id serial NOT NULL,
    section character varying(30) NOT NULL,
    ref_id integer NOT NULL,
    pagename character varying(50) NOT NULL,
    flags integer,
    latest_version integer NOT NULL
);



CREATE TABLE wiki_version (
    wiki_version_id serial NOT NULL,
    wiki_page_id integer NOT NULL,
    page_version integer NOT NULL,
    posted_by integer NOT NULL,
    refs text,
    last_modified_date timestamp with time zone DEFAULT now(),
    score integer,
    hits integer,
    create_date timestamp with time zone
);



CREATE TABLE wiki_page_link (
    from_wiki_page_id integer NOT NULL,
    to_wiki_page_id integer NOT NULL
);



CREATE VIEW project_activity_vw AS
    (((SELECT f.ref_id AS project_id, 'forum'::text AS section, f.forum_id AS ref_id, fm.forum_message_id AS subref_id, fm.subject AS description, fm.post_date AS activity_date, u.user_id, u.unix_name, u.firstname, u.lastname FROM forum f, forum_thread ft, forum_message fm, "user" u WHERE ((((u.user_id = fm.created_by) AND (ft.forum_thread_id = fm.forum_thread_id)) AND (ft.forum_id = f.forum_id)) AND ((f.section)::text = 'project'::text)) UNION SELECT t.project_id, 'trackeropen'::text AS section, t.tracker_id AS ref_id, ti.tracker_item_id AS subref_id, ti.summary AS description, ti.open_date AS activity_date, u.user_id, u.unix_name, u.firstname, u.lastname FROM tracker t, tracker_item ti, "user" u WHERE ((u.user_id = ti.submitted_by) AND (ti.tracker_id = t.tracker_id))) UNION SELECT t.project_id, 'trackerclose'::text AS section, t.tracker_id AS ref_id, ti.tracker_item_id AS subref_id, ti.summary AS description, ti.close_date AS activity_date, u.user_id, u.unix_name, u.firstname, u.lastname FROM tracker t, tracker_item ti, "user" u WHERE ((u.user_id = ti.last_modified_by) AND (ti.tracker_id = t.tracker_id))) UNION SELECT t.project_id, 'trackermod'::text AS section, t.tracker_id AS ref_id, ti.tracker_item_id AS subref_id, ti.summary AS description, ti.last_modified_date AS activity_date, u.user_id, u.unix_name, u.firstname, u.lastname FROM tracker t, tracker_item ti, "user" u WHERE ((u.user_id = ti.last_modified_by) AND (ti.tracker_id = t.tracker_id))) UNION SELECT sc.project_id, 'scmcommit'::text AS section, sc.scm_commit_id AS ref_id, 0 AS subref_id, sc.message_log AS description, sc.commit_date AS activity_date, u.user_id, u.unix_name, u.firstname, u.lastname FROM scm_commit sc, "user" u WHERE (u.user_id = sc.user_id);



CREATE TABLE trove_link_count (
    trove_category_id integer NOT NULL,
    section character varying(20) NOT NULL,
    link_count integer NOT NULL
);



CREATE TABLE docman_file (
    docman_file_id serial NOT NULL,
    docman_folder_id integer NOT NULL,
    description text,
    is_locked boolean DEFAULT true
);



CREATE TABLE docman_file_version (
    docman_file_version_id serial NOT NULL,
    docman_file_id integer NOT NULL,
    create_date timestamp with time zone DEFAULT now() NOT NULL,
    changes text,
    version_number double precision,
    created_by integer NOT NULL
);



CREATE TABLE scm_module_user (
    scm_module_id integer NOT NULL,
    user_id integer NOT NULL,
    "access" integer DEFAULT 0
);



CREATE TABLE cruisecontrol (
    project_id integer NOT NULL,
    builder text NOT NULL,
    log_type text NOT NULL,
    developer integer NOT NULL,
    last_modified_date timestamp with time zone DEFAULT now()
);



CREATE TABLE cruisecontrol_publisher (
    project_id integer NOT NULL,
    tracker_id integer NOT NULL
);



CREATE TABLE cruisecontrol_assignee (
    project_id integer NOT NULL,
    assignee integer NOT NULL
);



CREATE TABLE cruisecontrol_preference (
    project_id integer NOT NULL,
    name text NOT NULL,
    value text NOT NULL
);



CREATE TABLE cruisecontrol_module (
    project_id integer NOT NULL,
    scm_module_id integer NOT NULL
);



CREATE INDEX filesystem_sectionrefid ON filesystem USING btree (section, ref_id);



CREATE INDEX audit_trail_idx ON audit_trail USING btree (section, ref_id);



CREATE INDEX docmanfolder_projectidparentfolder ON docman_folder USING btree (project_id, parent_folder_id);



CREATE INDEX forum_sectionrefidispublic ON forum USING btree (section, ref_id, is_public);



CREATE INDEX forumthread_forumid ON forum_thread USING btree (forum_id);



CREATE INDEX forummessage_threadidpostdate ON forum_message USING btree (forum_thread_id, post_date);



CREATE INDEX userblog_useridpostdate ON user_blog USING btree (user_id, post_date);



CREATE UNIQUE INDEX frspackage_projectid ON frs_package USING btree (project_id, package_name);



CREATE UNIQUE INDEX frsrelease_packageidreleasename ON frs_release USING btree (frs_package_id, release_name);



CREATE INDEX filesystemdownload_filesystemiddownloaddate ON filesystem_download USING btree (filesystem_id, download_date);



CREATE INDEX mailman_projectidlistname ON mailman USING btree (project_id, list_name);



CREATE INDEX news_projectidpostdate ON news USING btree (project_id, post_date);



CREATE INDEX surveyquestion_projectid ON survey_question USING btree (project_id);



CREATE INDEX survey_projectidactive ON survey USING btree (project_id, is_active);



CREATE INDEX surveyresponse_surveyidquestioniddate ON survey_response USING btree (survey_id, question_id, post_date);



CREATE INDEX trovecat_parenttroveidtroveid ON trove_category USING btree (parent_trove_category_id, trove_category_id);



CREATE INDEX trovelink_trovecatid ON trove_link USING btree (trove_category_id);



CREATE INDEX role_projectidrolename ON role USING btree (project_id, role_name);



CREATE INDEX tracker_projectiddatatypeispublic ON tracker USING btree (project_id, datatype, is_public);



CREATE INDEX trackeritem_trackeridstatusid ON tracker_item USING btree (tracker_id, status_id, tracker_item_id);



CREATE INDEX trackeritem_trackeridsubmittedbystatusid ON tracker_item USING btree (tracker_id, submitted_by, status_id, tracker_item_id);



CREATE INDEX trackeritemrelation_relatedtrackeritemidtrackeritemid ON tracker_item_relation USING btree (related_tracker_item_id, tracker_item_id);



CREATE INDEX trackeritemassignee_assigneetrackeritemid ON tracker_item_assignee USING btree (assignee, tracker_item_id);



CREATE INDEX trackermessage_trackeritemidaddate ON tracker_item_message USING btree (tracker_item_id, adddate);



CREATE INDEX trackercannedresponse_trackerid ON tracker_canned_response USING btree (tracker_id);



CREATE INDEX trackerextrafield_trackeridfieldorder ON tracker_extra_field USING btree (tracker_id, field_order);



CREATE INDEX trackerextrafieldelement_trackerextrafieldidsortorder ON tracker_extra_field_element USING btree (tracker_extra_field_id, sort_order);



CREATE INDEX trackerextrafielddata_extrafieldidtrackeritem ON tracker_extra_field_data USING btree (tracker_item_id, tracker_extra_field_id);



CREATE UNIQUE INDEX trackeritemscmcommit_trackeritemidscmcommitid ON tracker_item_scm_commit USING btree (tracker_item_id, scm_commit_id);



CREATE INDEX trackerquery_trackeriduserid ON tracker_query USING btree (tracker_id, user_id);



CREATE UNIQUE INDEX wikipage_secionrefidpagename ON wiki_page USING btree (section, ref_id, pagename);



CREATE UNIQUE INDEX wikiversion_wikipageidpageversion ON wiki_version USING btree (wiki_page_id, page_version);



CREATE INDEX forummessage_createdbypostdate ON forum_message USING btree (created_by, post_date);



CREATE INDEX scmcommit_useridcommitdate ON scm_commit USING btree (user_id, commit_date);



CREATE INDEX trackeritem_lastmodbylastmoddate ON tracker_item USING btree (last_modified_by, last_modified_date);



CREATE INDEX trackeritem_lastmodbyclosedate ON tracker_item USING btree (last_modified_by, close_date);



CREATE INDEX trackeritem_submittedbyopendate ON tracker_item USING btree (submitted_by, open_date);



CREATE INDEX scmcommit_projectiddate ON scm_commit USING btree (project_id, commit_date);



CREATE INDEX trackeritem_trackeridopendate ON tracker_item USING btree (tracker_id, open_date);



CREATE INDEX trackeritem_trackeridclosedate ON tracker_item USING btree (tracker_id, close_date);



CREATE INDEX trackeritem_trackeridlastmoddate ON tracker_item USING btree (tracker_id, last_modified_date);



CREATE INDEX docmanfile_docmanfolderid ON docman_file USING btree (docman_folder_id);



CREATE INDEX docmanfileversion_docmanfileid ON docman_file_version USING btree (docman_file_version_id);



CREATE INDEX cruisecontrolpublisher_projectidtrackerid ON cruisecontrol_publisher USING btree (project_id, tracker_id);



CREATE INDEX cruisecontrolassignee_projectidassignee ON cruisecontrol_assignee USING btree (project_id, assignee);



CREATE INDEX cruisecontrolmodule_projectidscmmoduleid ON cruisecontrol_module USING btree (project_id, scm_module_id);



ALTER TABLE ONLY deleted_project
    ADD CONSTRAINT deleted_project_pkey PRIMARY KEY (unix_group_name);



ALTER TABLE ONLY project
    ADD CONSTRAINT project_pkey PRIMARY KEY (project_id);



ALTER TABLE ONLY project
    ADD CONSTRAINT project_unix_name_key UNIQUE (unix_name);



ALTER TABLE ONLY country_code
    ADD CONSTRAINT country_code_pkey PRIMARY KEY (ccode);



ALTER TABLE ONLY theme
    ADD CONSTRAINT theme_pkey PRIMARY KEY (theme_id);



ALTER TABLE ONLY "language"
    ADD CONSTRAINT language_pkey PRIMARY KEY (language_id);



ALTER TABLE ONLY "user"
    ADD CONSTRAINT user_pkey PRIMARY KEY (user_id);



ALTER TABLE ONLY "user"
    ADD CONSTRAINT user_unix_name_key UNIQUE (unix_name);



ALTER TABLE ONLY site_admin
    ADD CONSTRAINT site_admin_pkey PRIMARY KEY (user_id);



ALTER TABLE ONLY filesystem
    ADD CONSTRAINT filesystem_pkey PRIMARY KEY (filesystem_id);



ALTER TABLE ONLY stats_project_page_view
    ADD CONSTRAINT stats_project_page_view_pkey PRIMARY KEY (project_id, count_date);



ALTER TABLE ONLY stats_site_page_view
    ADD CONSTRAINT stats_site_page_view_pkey PRIMARY KEY (count_date);



ALTER TABLE ONLY monitor
    ADD CONSTRAINT monitor_pkey PRIMARY KEY (section, ref_id, user_id);



ALTER TABLE ONLY audit_trail
    ADD CONSTRAINT audit_trail_pkey PRIMARY KEY (audit_trail_id);



ALTER TABLE ONLY unix_shell
    ADD CONSTRAINT unix_shell_pkey PRIMARY KEY (unix_shell_id);



ALTER TABLE ONLY user_unix
    ADD CONSTRAINT user_unix_pkey PRIMARY KEY (user_id);



ALTER TABLE ONLY scm_server
    ADD CONSTRAINT scm_server_pkey PRIMARY KEY (scm_server_id);



ALTER TABLE ONLY docman_folder
    ADD CONSTRAINT docman_folder_pkey PRIMARY KEY (docman_folder_id);



ALTER TABLE ONLY project_scm
    ADD CONSTRAINT project_scm_pkey PRIMARY KEY (project_id);



ALTER TABLE ONLY forum
    ADD CONSTRAINT forum_pkey PRIMARY KEY (forum_id);



ALTER TABLE ONLY forum_thread
    ADD CONSTRAINT forum_thread_pkey PRIMARY KEY (forum_thread_id);



ALTER TABLE ONLY forum_message
    ADD CONSTRAINT forum_message_pkey PRIMARY KEY (forum_message_id);



ALTER TABLE ONLY user_blog
    ADD CONSTRAINT user_blog_pkey PRIMARY KEY (user_blog_id);



ALTER TABLE ONLY frs_package
    ADD CONSTRAINT frs_package_pkey PRIMARY KEY (frs_package_id);



ALTER TABLE ONLY frs_release
    ADD CONSTRAINT frs_release_pkey PRIMARY KEY (frs_release_id);



ALTER TABLE ONLY deleted_mailing_list
    ADD CONSTRAINT deleted_mailing_list_pkey PRIMARY KEY (mailing_list_name);



ALTER TABLE ONLY mailman
    ADD CONSTRAINT mailman_pkey PRIMARY KEY (mailman_id);



ALTER TABLE ONLY news
    ADD CONSTRAINT news_pkey PRIMARY KEY (news_id);



ALTER TABLE ONLY news_count
    ADD CONSTRAINT news_count_pkey PRIMARY KEY (project_id);



ALTER TABLE ONLY user_session
    ADD CONSTRAINT user_session_pkey PRIMARY KEY (session_hash);



ALTER TABLE ONLY snippet
    ADD CONSTRAINT snippet_pkey PRIMARY KEY (snippet_id);



ALTER TABLE ONLY survey_question
    ADD CONSTRAINT survey_question_pkey PRIMARY KEY (survey_question_id);



ALTER TABLE ONLY survey
    ADD CONSTRAINT survey_pkey PRIMARY KEY (survey_id);



ALTER TABLE ONLY survey_response
    ADD CONSTRAINT survey_response_pkey PRIMARY KEY (user_id, survey_id, question_id);



ALTER TABLE ONLY trove_category
    ADD CONSTRAINT trove_category_pkey PRIMARY KEY (trove_category_id);



ALTER TABLE ONLY trove_link
    ADD CONSTRAINT trove_link_pkey PRIMARY KEY (section, ref_id, trove_category_id);



ALTER TABLE ONLY role
    ADD CONSTRAINT role_pkey PRIMARY KEY (role_id);



ALTER TABLE ONLY role_setting
    ADD CONSTRAINT role_setting_pkey PRIMARY KEY (role_id, section, ref_id);



ALTER TABLE ONLY user_project
    ADD CONSTRAINT user_project_pkey PRIMARY KEY (user_id, project_id);



ALTER TABLE ONLY user_preference
    ADD CONSTRAINT user_preference_pkey PRIMARY KEY (user_id, preference_name);



ALTER TABLE ONLY tracker
    ADD CONSTRAINT tracker_pkey PRIMARY KEY (tracker_id);



ALTER TABLE ONLY tracker_item
    ADD CONSTRAINT tracker_item_pkey PRIMARY KEY (tracker_item_id);



ALTER TABLE ONLY tracker_time_code
    ADD CONSTRAINT tracker_time_code_pkey PRIMARY KEY (tracker_time_code_id);



ALTER TABLE ONLY tracker_item_time
    ADD CONSTRAINT tracker_item_time_pkey PRIMARY KEY (tracker_item_time_id);



ALTER TABLE ONLY tracker_item_relation
    ADD CONSTRAINT tracker_item_relation_pkey PRIMARY KEY (tracker_item_id, related_tracker_item_id);



ALTER TABLE ONLY tracker_item_assignee
    ADD CONSTRAINT tracker_item_assignee_pkey PRIMARY KEY (tracker_item_id, assignee);



ALTER TABLE ONLY tracker_item_message
    ADD CONSTRAINT tracker_item_message_pkey PRIMARY KEY (tracker_item_message_id);



ALTER TABLE ONLY tracker_canned_response
    ADD CONSTRAINT tracker_canned_response_pkey PRIMARY KEY (tracker_canned_response_id);



ALTER TABLE ONLY notification_queue
    ADD CONSTRAINT notification_queue_pkey PRIMARY KEY (notification_queue_id);



ALTER TABLE ONLY scm_user_stats
    ADD CONSTRAINT scm_user_stats_pkey PRIMARY KEY (stat_date, project_id, user_id);



ALTER TABLE ONLY scm_project_stats
    ADD CONSTRAINT scm_project_stats_pkey PRIMARY KEY (stat_date, project_id);



ALTER TABLE ONLY plugin
    ADD CONSTRAINT plugin_pkey PRIMARY KEY (plugin_id);



ALTER TABLE ONLY project_plugin
    ADD CONSTRAINT project_plugin_pkey PRIMARY KEY (project_id, plugin_id);



ALTER TABLE ONLY user_plugin
    ADD CONSTRAINT user_plugin_pkey PRIMARY KEY (user_id, plugin_id);



ALTER TABLE ONLY user_relation
    ADD CONSTRAINT user_relation_pkey PRIMARY KEY (user_id, related_user_id);



ALTER TABLE ONLY user_watched_project
    ADD CONSTRAINT user_watched_project_pkey PRIMARY KEY (user_id, project_id);



ALTER TABLE ONLY tracker_extra_field
    ADD CONSTRAINT tracker_extra_field_pkey PRIMARY KEY (tracker_extra_field_id);



ALTER TABLE ONLY tracker_extra_field_element
    ADD CONSTRAINT tracker_extra_field_element_pkey PRIMARY KEY (element_id);



ALTER TABLE ONLY tracker_extra_field_data
    ADD CONSTRAINT tracker_extra_field_data_pkey PRIMARY KEY (tracker_extra_field_data_id);



ALTER TABLE ONLY project_join_request
    ADD CONSTRAINT project_join_request_pkey PRIMARY KEY (project_id, user_id);



ALTER TABLE ONLY scm_module
    ADD CONSTRAINT scm_module_pkey PRIMARY KEY (scm_module_id);



ALTER TABLE ONLY scm_preference
    ADD CONSTRAINT scm_preference_pkey PRIMARY KEY (project_id);



ALTER TABLE ONLY scm_commit
    ADD CONSTRAINT scm_commit_pkey PRIMARY KEY (scm_commit_id);



ALTER TABLE ONLY scm_commit_file
    ADD CONSTRAINT scm_commit_file_pkey PRIMARY KEY (scm_commit_id, modified_file);



ALTER TABLE ONLY tracker_query
    ADD CONSTRAINT tracker_query_pkey PRIMARY KEY (tracker_query_id);



ALTER TABLE ONLY tracker_query_field
    ADD CONSTRAINT tracker_query_field_pkey PRIMARY KEY (tracker_query_id, query_field_type, query_field_id);



ALTER TABLE ONLY wiki_page
    ADD CONSTRAINT wiki_page_pkey PRIMARY KEY (wiki_page_id);



ALTER TABLE ONLY wiki_version
    ADD CONSTRAINT wiki_version_pkey PRIMARY KEY (wiki_version_id);



ALTER TABLE ONLY wiki_page_link
    ADD CONSTRAINT wiki_page_link_pkey PRIMARY KEY (from_wiki_page_id, to_wiki_page_id);



ALTER TABLE ONLY trove_link_count
    ADD CONSTRAINT trove_link_count_pkey PRIMARY KEY (trove_category_id, section);



ALTER TABLE ONLY docman_file
    ADD CONSTRAINT docman_file_pkey PRIMARY KEY (docman_file_id);



ALTER TABLE ONLY docman_file_version
    ADD CONSTRAINT docman_file_version_pkey PRIMARY KEY (docman_file_version_id);



ALTER TABLE ONLY scm_module_user
    ADD CONSTRAINT scm_module_user_pkey PRIMARY KEY (scm_module_id, user_id);



ALTER TABLE ONLY cruisecontrol
    ADD CONSTRAINT cruisecontrol_pkey PRIMARY KEY (project_id);



ALTER TABLE ONLY cruisecontrol_publisher
    ADD CONSTRAINT cruisecontrol_publisher_pkey PRIMARY KEY (project_id, tracker_id);



ALTER TABLE ONLY cruisecontrol_assignee
    ADD CONSTRAINT cruisecontrol_assignee_pkey PRIMARY KEY (project_id, assignee);



ALTER TABLE ONLY cruisecontrol_preference
    ADD CONSTRAINT cruisecontrol_preference_pkey PRIMARY KEY (project_id, name);



ALTER TABLE ONLY cruisecontrol_module
    ADD CONSTRAINT cruisecontrol_module_pkey PRIMARY KEY (project_id, scm_module_id);



ALTER TABLE ONLY "user"
    ADD CONSTRAINT countrycode_fk FOREIGN KEY (ccode) REFERENCES country_code(ccode);



ALTER TABLE ONLY "user"
    ADD CONSTRAINT languageid_fk FOREIGN KEY (language_id) REFERENCES "language"(language_id);



ALTER TABLE ONLY "user"
    ADD CONSTRAINT themeid_fk FOREIGN KEY (theme_id) REFERENCES theme(theme_id);



ALTER TABLE ONLY site_admin
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id) ON DELETE CASCADE;



ALTER TABLE ONLY filesystem
    ADD CONSTRAINT userid_fk FOREIGN KEY (posted_by) REFERENCES "user"(user_id);



ALTER TABLE ONLY monitor
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);



ALTER TABLE ONLY audit_trail
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);



ALTER TABLE ONLY user_unix
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);



ALTER TABLE ONLY user_unix
    ADD CONSTRAINT unixshellid_fk FOREIGN KEY (unix_shell_id) REFERENCES unix_shell(unix_shell_id);



ALTER TABLE ONLY docman_folder
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY project_scm
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY project_scm
    ADD CONSTRAINT scmserverid_fk FOREIGN KEY (scm_server_id) REFERENCES scm_server(scm_server_id);



ALTER TABLE ONLY forum_thread
    ADD CONSTRAINT forumid_fk FOREIGN KEY (forum_id) REFERENCES forum(forum_id) ON DELETE CASCADE;



ALTER TABLE ONLY forum_thread
    ADD CONSTRAINT userid_fk FOREIGN KEY (created_by) REFERENCES "user"(user_id);



ALTER TABLE ONLY forum_message
    ADD CONSTRAINT forumthreadid_fk FOREIGN KEY (forum_thread_id) REFERENCES forum_thread(forum_thread_id) ON DELETE CASCADE;



ALTER TABLE ONLY forum_message
    ADD CONSTRAINT userid_fk FOREIGN KEY (created_by) REFERENCES "user"(user_id);



ALTER TABLE ONLY user_blog
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);



ALTER TABLE ONLY frs_package
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY frs_release
    ADD CONSTRAINT frspackageid_fk FOREIGN KEY (frs_package_id) REFERENCES frs_package(frs_package_id) ON DELETE CASCADE;



ALTER TABLE ONLY frs_release
    ADD CONSTRAINT userid_fk FOREIGN KEY (released_by) REFERENCES "user"(user_id);



ALTER TABLE ONLY filesystem_download
    ADD CONSTRAINT filesystemid_fk FOREIGN KEY (filesystem_id) REFERENCES filesystem(filesystem_id) ON DELETE CASCADE;



ALTER TABLE ONLY mailman
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY mailman
    ADD CONSTRAINT userid_fk FOREIGN KEY (created_by) REFERENCES "user"(user_id);



ALTER TABLE ONLY news
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY news
    ADD CONSTRAINT userid_fk FOREIGN KEY (submitted_by) REFERENCES "user"(user_id);



ALTER TABLE ONLY news_count
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY user_session
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);



ALTER TABLE ONLY snippet
    ADD CONSTRAINT userid_fk FOREIGN KEY (created_by) REFERENCES "user"(user_id);



ALTER TABLE ONLY survey_question
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY survey
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY survey_response
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);



ALTER TABLE ONLY trove_category
    ADD CONSTRAINT parenttrovecatid_fk FOREIGN KEY (parent_trove_category_id) REFERENCES trove_category(trove_category_id) ON DELETE CASCADE;



ALTER TABLE ONLY trove_link
    ADD CONSTRAINT trovecategoryid_fk FOREIGN KEY (trove_category_id) REFERENCES trove_category(trove_category_id) ON DELETE CASCADE;



ALTER TABLE ONLY role
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY role_setting
    ADD CONSTRAINT roleid_fk FOREIGN KEY (role_id) REFERENCES role(role_id) ON DELETE CASCADE;



ALTER TABLE ONLY user_project
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);



ALTER TABLE ONLY user_project
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY user_project
    ADD CONSTRAINT roleid_fk FOREIGN KEY (role_id) REFERENCES role(role_id) ON DELETE CASCADE;



ALTER TABLE ONLY user_preference
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);



ALTER TABLE ONLY tracker
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY tracker_item
    ADD CONSTRAINT trackerid_fk FOREIGN KEY (tracker_id) REFERENCES tracker(tracker_id) ON DELETE CASCADE;



ALTER TABLE ONLY tracker_item
    ADD CONSTRAINT submittedby_fk FOREIGN KEY (submitted_by) REFERENCES "user"(user_id);



ALTER TABLE ONLY tracker_item_time
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);



ALTER TABLE ONLY tracker_item_time
    ADD CONSTRAINT trackeritemid_fk FOREIGN KEY (tracker_item_id) REFERENCES tracker_item(tracker_item_id) ON DELETE CASCADE;



ALTER TABLE ONLY tracker_item_time
    ADD CONSTRAINT trackertimecodeid_fk FOREIGN KEY (tracker_time_code_id) REFERENCES tracker_time_code(tracker_time_code_id) ON DELETE CASCADE;



ALTER TABLE ONLY tracker_item_relation
    ADD CONSTRAINT trackeritemid_fk FOREIGN KEY (tracker_item_id) REFERENCES tracker_item(tracker_item_id) ON DELETE CASCADE;



ALTER TABLE ONLY tracker_item_relation
    ADD CONSTRAINT relatedtrackeritemid_fk FOREIGN KEY (related_tracker_item_id) REFERENCES tracker_item(tracker_item_id) ON DELETE CASCADE;



ALTER TABLE ONLY tracker_item_assignee
    ADD CONSTRAINT trackeritemid_fk FOREIGN KEY (tracker_item_id) REFERENCES tracker_item(tracker_item_id) ON DELETE CASCADE;



ALTER TABLE ONLY tracker_item_assignee
    ADD CONSTRAINT userid_fk FOREIGN KEY (assignee) REFERENCES "user"(user_id);



ALTER TABLE ONLY tracker_item_message
    ADD CONSTRAINT trackeritemid_fk FOREIGN KEY (tracker_item_id) REFERENCES tracker_item(tracker_item_id) ON DELETE CASCADE;



ALTER TABLE ONLY tracker_item_message
    ADD CONSTRAINT userid_fk FOREIGN KEY (submitted_by) REFERENCES "user"(user_id);



ALTER TABLE ONLY tracker_canned_response
    ADD CONSTRAINT trackerid_fk FOREIGN KEY (tracker_id) REFERENCES tracker(tracker_id) ON DELETE CASCADE;



ALTER TABLE ONLY notification_queue
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);



ALTER TABLE ONLY scm_user_stats
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY scm_user_stats
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);



ALTER TABLE ONLY scm_project_stats
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY plugin_dependency
    ADD CONSTRAINT pluginid_fk FOREIGN KEY (plugin_id) REFERENCES plugin(plugin_id) ON DELETE CASCADE;



ALTER TABLE ONLY plugin_dependency
    ADD CONSTRAINT dependsonpluginid_fk FOREIGN KEY (dependson_plugin_id) REFERENCES plugin(plugin_id);



ALTER TABLE ONLY project_plugin
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY project_plugin
    ADD CONSTRAINT pluginid_fk FOREIGN KEY (plugin_id) REFERENCES plugin(plugin_id) ON DELETE CASCADE;



ALTER TABLE ONLY user_plugin
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id) ON DELETE CASCADE;



ALTER TABLE ONLY user_plugin
    ADD CONSTRAINT pluginid_fk FOREIGN KEY (plugin_id) REFERENCES plugin(plugin_id) ON DELETE CASCADE;



ALTER TABLE ONLY user_relation
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id) ON DELETE CASCADE;



ALTER TABLE ONLY user_relation
    ADD CONSTRAINT relateduserid_fk FOREIGN KEY (related_user_id) REFERENCES "user"(user_id) ON DELETE CASCADE;



ALTER TABLE ONLY user_watched_project
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id) ON DELETE CASCADE;



ALTER TABLE ONLY user_watched_project
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY tracker_extra_field
    ADD CONSTRAINT trackerid_fk FOREIGN KEY (tracker_id) REFERENCES tracker(tracker_id) ON DELETE CASCADE;



ALTER TABLE ONLY tracker_extra_field_element
    ADD CONSTRAINT trackerextrafieldid_fk FOREIGN KEY (tracker_extra_field_id) REFERENCES tracker_extra_field(tracker_extra_field_id) ON DELETE CASCADE;



ALTER TABLE ONLY tracker_extra_field_data
    ADD CONSTRAINT trackeritemid_fk FOREIGN KEY (tracker_item_id) REFERENCES tracker_item(tracker_item_id) ON DELETE CASCADE;



ALTER TABLE ONLY tracker_extra_field_data
    ADD CONSTRAINT trackerextrafieldid_fk FOREIGN KEY (tracker_extra_field_id) REFERENCES tracker_extra_field(tracker_extra_field_id) ON DELETE CASCADE;



ALTER TABLE ONLY project_join_request
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY project_join_request
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id) ON DELETE CASCADE;



ALTER TABLE ONLY scm_module
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY scm_preference
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY scm_commit
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY scm_commit
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);



ALTER TABLE ONLY tracker_item_scm_commit
    ADD CONSTRAINT trackeritemid_fk FOREIGN KEY (tracker_item_id) REFERENCES tracker_item(tracker_item_id) ON DELETE CASCADE;



ALTER TABLE ONLY tracker_item_scm_commit
    ADD CONSTRAINT scmcommitid_fk FOREIGN KEY (scm_commit_id) REFERENCES scm_commit(scm_commit_id) ON DELETE CASCADE;



ALTER TABLE ONLY scm_commit_file
    ADD CONSTRAINT scmcommitid_fk FOREIGN KEY (scm_commit_id) REFERENCES scm_commit(scm_commit_id) ON DELETE CASCADE;



ALTER TABLE ONLY tracker_query
    ADD CONSTRAINT trackerid_fk FOREIGN KEY (tracker_id) REFERENCES tracker(tracker_id) ON DELETE CASCADE;



ALTER TABLE ONLY tracker_query
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id);



ALTER TABLE ONLY tracker_query_field
    ADD CONSTRAINT trackerqueryid_fk FOREIGN KEY (tracker_query_id) REFERENCES tracker_query(tracker_query_id) ON DELETE CASCADE;



ALTER TABLE ONLY wiki_version
    ADD CONSTRAINT wikipageid_fk FOREIGN KEY (wiki_page_id) REFERENCES wiki_page(wiki_page_id) ON DELETE CASCADE;



ALTER TABLE ONLY wiki_version
    ADD CONSTRAINT userid_fk FOREIGN KEY (posted_by) REFERENCES "user"(user_id);



ALTER TABLE ONLY wiki_page_link
    ADD CONSTRAINT fromwikipageid_fk FOREIGN KEY (from_wiki_page_id) REFERENCES wiki_page(wiki_page_id) ON DELETE CASCADE;



ALTER TABLE ONLY wiki_page_link
    ADD CONSTRAINT towikipageid_fk FOREIGN KEY (to_wiki_page_id) REFERENCES wiki_page(wiki_page_id) ON DELETE CASCADE;



ALTER TABLE ONLY trove_link_count
    ADD CONSTRAINT trovecategory_fk FOREIGN KEY (trove_category_id) REFERENCES trove_category(trove_category_id) ON DELETE CASCADE;



ALTER TABLE ONLY docman_file
    ADD CONSTRAINT docmanfolderid_fk FOREIGN KEY (docman_folder_id) REFERENCES docman_folder(docman_folder_id) ON DELETE CASCADE;



ALTER TABLE ONLY docman_file_version
    ADD CONSTRAINT docmanfileid_fk FOREIGN KEY (docman_file_id) REFERENCES docman_file(docman_file_id) ON DELETE CASCADE;



ALTER TABLE ONLY docman_file_version
    ADD CONSTRAINT userid_fk FOREIGN KEY (created_by) REFERENCES "user"(user_id) ON DELETE CASCADE;



ALTER TABLE ONLY scm_module_user
    ADD CONSTRAINT scmmoduleid_fk FOREIGN KEY (scm_module_id) REFERENCES scm_module(scm_module_id) ON DELETE CASCADE;



ALTER TABLE ONLY scm_module_user
    ADD CONSTRAINT userid_fk FOREIGN KEY (user_id) REFERENCES "user"(user_id) ON DELETE CASCADE;



ALTER TABLE ONLY cruisecontrol
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY cruisecontrol
    ADD CONSTRAINT userid_fk FOREIGN KEY (developer) REFERENCES "user"(user_id) ON DELETE CASCADE;



ALTER TABLE ONLY cruisecontrol_publisher
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY cruisecontrol_publisher
    ADD CONSTRAINT trackerid_fk FOREIGN KEY (tracker_id) REFERENCES tracker(tracker_id) ON DELETE CASCADE;



ALTER TABLE ONLY cruisecontrol_assignee
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY cruisecontrol_assignee
    ADD CONSTRAINT userid_fk FOREIGN KEY (assignee) REFERENCES "user"(user_id) ON DELETE CASCADE;



ALTER TABLE ONLY cruisecontrol_preference
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY cruisecontrol_module
    ADD CONSTRAINT projectid_fk FOREIGN KEY (project_id) REFERENCES project(project_id) ON DELETE CASCADE;



ALTER TABLE ONLY cruisecontrol_module
    ADD CONSTRAINT scmmoduleid_fk FOREIGN KEY (scm_module_id) REFERENCES scm_module(scm_module_id) ON DELETE CASCADE;



CREATE TRIGGER news_insert_trigg
    AFTER INSERT ON news
    FOR EACH ROW
    EXECUTE PROCEDURE news_insert_agg();



CREATE TRIGGER forum_message_insertdelete_trigg
    AFTER INSERT OR DELETE ON forum_message
    FOR EACH ROW
    EXECUTE PROCEDURE forum_insertdelete_agg();



CREATE TRIGGER tracker_item_update_trigg
    AFTER UPDATE ON tracker_item
    FOR EACH ROW
    EXECUTE PROCEDURE tracker_update_agg();



CREATE RULE project_delete_rule AS ON DELETE TO project DO INSERT INTO deleted_project (unix_group_name) VALUES (old.unix_name);



CREATE RULE forum_thread_insert_rule AS ON INSERT TO forum_thread DO UPDATE forum SET thread_count = (forum.thread_count + 1), most_recent_date = now() WHERE (forum.forum_id = new.forum_id);



CREATE RULE forum_thread_delete_rule AS ON DELETE TO forum_thread DO UPDATE forum SET thread_count = (forum.thread_count - 1) WHERE (forum.forum_id = old.forum_id);



CREATE RULE user_blog_insert_forum_rule AS ON INSERT TO user_blog DO INSERT INTO forum (section, ref_id, forum_name, description) VALUES ('userblog'::character varying, new.user_blog_id, ('userblog-'::text || (new.user_blog_id)::text), new.subject);



CREATE RULE user_blog_delete_forum_rule AS ON DELETE TO user_blog DO DELETE FROM forum WHERE (((forum.section)::text = 'userblog'::text) AND (forum.ref_id = old.user_blog_id));



CREATE RULE forum_message_insert_rule AS ON INSERT TO forum_message DO UPDATE forum_thread SET message_count = (forum_thread.message_count + 1), most_recent_date = now() WHERE (forum_thread.forum_thread_id = new.forum_thread_id);



CREATE RULE forum_message_delete_rule AS ON DELETE TO forum_message DO UPDATE forum_thread SET message_count = (forum_thread.message_count - 1) WHERE (forum_thread.forum_thread_id = old.forum_thread_id);



CREATE RULE filesystem_download_rule AS ON INSERT TO filesystem_download DO UPDATE filesystem SET download_count = (filesystem.download_count + 1) WHERE (filesystem.filesystem_id = new.filesystem_id);



CREATE RULE mailman_insert_forum_rule AS ON INSERT TO mailman DO INSERT INTO forum (section, ref_id, forum_name, description) VALUES ('mailman'::character varying, new.mailman_id, ('mailman-'::text || (new.mailman_id)::text), new.list_name);



CREATE RULE mailman_delete_forum_rule AS ON DELETE TO mailman DO DELETE FROM forum WHERE (((forum.section)::text = 'mailman'::text) AND (forum.ref_id = old.mailman_id));



CREATE RULE mailman_delete_rule AS ON DELETE TO mailman DO INSERT INTO deleted_mailing_list (mailing_list_name) VALUES (old.list_name);



CREATE RULE news_insert_rule AS ON INSERT TO news DO UPDATE news_count SET total = (news_count.total + 1) WHERE (news_count.project_id = new.project_id);



CREATE RULE news_delete_rule AS ON DELETE TO news DO UPDATE news_count SET total = (news_count.total - 1) WHERE (news_count.project_id = old.project_id);



CREATE RULE news_insert_forum_rule AS ON INSERT TO news DO INSERT INTO forum (section, ref_id, forum_name, description) VALUES ('news'::character varying, new.news_id, ('news-'::text || (new.news_id)::text), new.summary);



CREATE RULE news_delete_forum_rule AS ON DELETE TO news DO DELETE FROM forum WHERE (((forum.section)::text = 'news'::text) AND (forum.ref_id = old.news_id));



CREATE RULE trackeritem_insert_rule AS ON INSERT TO tracker_item DO UPDATE tracker SET item_total = (tracker.item_total + 1), open_count = (tracker.open_count + 1) WHERE (tracker.tracker_id = new.tracker_id);



CREATE RULE tracker_item_delete_rule AS ON DELETE TO tracker_item DO UPDATE tracker SET item_total = (tracker.item_total - 1), open_count = CASE WHEN (old.status_id = 1) THEN (tracker.open_count - 1) ELSE tracker.open_count END WHERE (tracker.tracker_id = old.tracker_id);



COMMENT ON SCHEMA public IS 'Standard public schema';

-- Insert default data
INSERT INTO unix_shell(shell_name,path) values ('Bash','/bin/bash');
INSERT INTO unix_shell(shell_name,path) values ('Restricted CVS Shell','/bin/cvssh.pl');


INSERT INTO scm_server(scm_type,hostname) values ('CVS','cvs.');
INSERT INTO scm_server(scm_type,hostname) values ('SVN','svn.');


