<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id: GFProjectPlugin.php 3226 2008-08-06 17:58:08Z bigdisk $
 * @author Tim Perdue tim@gforge.org
 * @date 2005-11-10
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

require_once('plugin/GFPlugin.php');
require_once('core/Role.php');

/**
 *	This interface defines plugins that are used at the 
 *	project level (examples: tracker, docman, projman)
 *  The interface between ProjectPlugins and the core 
 *  is very slim - only a handful of glue points are required.
 *  These glue points include adding/removing projects and members
 *
 *	Project plugins are not initialized until a Project object
 *	is created.
 */
interface GFProjectPlugin extends GFPlugin {

	function __construct();

	/**
	 * 	The addMember listener - this hook will fire
	 *	whenever a member is added to a project.
	 *	@param	User	User object
	 *	@return	boolean
	 */
	function addMemberListener($params);

	/**
	 * 	The removeMember listener - this hook will fire
	 *	whenever a member is removed from a project.
	 *	@param	User	User object
	 *	@return	boolean
	 */
	function removeMemberListener($params);

	/**
	 * 	The approveProject listener - this hook will fire
	 *	when a project is approved.
	 *	@param	Project	the project object
	 *	@return	boolean
	 */
	function approveProjectListener($params);

	/**
	 * 	The deleteProject listener - this hook will fire
	 *	when a project is deleted.
	 *	@return	boolean
	 */
	function deleteProjectListener();

	/**
	 * 	The checkPermission - this listener will fire
	 *	when permissions are being checked for this project.
	 *	@param	Array	An associative array containing 
	 *	'section_name' a name like 'tracker' or 'tracker_item'
	 *	'section_id'=>id (the id of the section, for example a specific tracker)
	 *	'subsection_id'=>id (the id of the subsection, for example an tracker_item id)
	 *	'perm_level'=>int (the value, such a 1 for read, 2 for write, that is being requested)
	 *	@return	boolean
	 * /
	function checkPermission($params);
*/

	/**
	 * 	The getRoleChoices listener - this hook will fire
	 *	when a new role is added or one is going to be updated.
	 * 	It returns an array of role settings
	 * 	@param $params array of params
	 *	@return	boolean
	 */
	function getRoleChoices($params);

	/**
	 * 	The getObserverRoleChoices listener - this hook will fire
	 *	when the observer role is modified.
	 * 	It returns an array of role settings or null
	 * 	@param $params	array of params
	 *	@return	array or null
	 */
	function getObserverRoleChoices($params);
	
	/**
	 * This method will be called when this plugin is enabled
	 */
	function enableInProject(Project $project);

	/**
	 * This method will be called when this plugin is disabled
	 */
	function disableFromProject();
}

?>
