<?php

/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version $Id$
 * @author Daniel A. Perez	daniel@gforgegroup.com
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

require_once('lib/core/Filesystem.php');
require_once('lib/core/FilesystemPeer.php');
require_once('plugins/docman/lib/DocmanFile.php');
require_once('plugins/docman/lib/DocmanFilePeer.php');
require_once('plugins/docman/lib/DocmanFileVersion.php');
require_once('plugins/docman/lib/DocmanFileVersionPeer.php');
require_once('plugins/docman/lib/DocmanFolder.php');
require_once('plugins/docman/lib/DocmanFolderPeer.php');
require_once('lib/exceptions/PermissionDeniedException.php');
require_once('Validator.php');

$session = Session::getSession();
$Lang = $session->getLanguage();

$project = GFUrl::getUrl()->getProject();

$id = Validator::sanitizeInt($_REQUEST['id']);

if (!$session->isLoggedIn()) {
	throw new PermissionDeniedException();
}

$df = DocmanFilePeer::retrieveByPK($id);
if (!is_object($df) 
	|| $df->getDocmanFolder()->getProjectId()!=$project->getProjectId()
	|| !$df->userCanCreate()) {
	throw new PermissionDeniedException();
}

$errors=array();

try {

	//docs can be either uploaded or edited inline
	if (isset($_POST['action_type']) && $_POST['action_type'] == DocmanFile::EDITED_INLINE) {
		$file_contents = $_POST['message'];
		$file_name = $_POST['file_name'];
	} else {
		$file = $_FILES['doc'];
		$error = $file['error'];
		$filename=$file['name'];
		if ($error > 0) {
			$fileerrors = StringUtils::getFileUploadErrorString($error, $filename);
			throw new InvalidDataException($fileerrors);
		}
	}
	$con = Propel::getConnection(DocmanFolderPeer::DATABASE_NAME);
	$con->begin();
	$dfv = new DocmanFileVersion();
	$dfv->setDocmanFileId($df->getDocmanFileId());
	$dfv->setChanges(Validator::sanitizeString($_REQUEST['changes']));
	//$df->save();
	$dfv->save();
	// create the file in the FS
	$newfile = new Filesystem();
	$newfile->setRefId($dfv->getPrimaryKey());
	$newfile->setSection(DocmanFileVersion::SECTION);
	$newfile->setPostedBy($session->getUser()->getUserId());
	if (isset($_POST['action_type']) && $_POST['action_type'] == DocmanFile::EDITED_INLINE) {
		$newfile->setFileType('text/html');
		$newfile->setFileName($file_name);
		$newfile->save();
		$newfile->setFileDataFromString($file_contents);
	} else {
		$newfile->setFileType($file['type']);
		$newfile->setFileName($file['name']);
		$newfile->save();
		$newfile->setFileDataFromPath($file['tmp_name']);
	}
	$con->commit();

	if ($dfv->getIsApproved()) {
		$feedback = $Lang->getText('DocmanFile.AddFeedback');
	} else {
		$feedback = $Lang->getText('DocmanFile.AddQueuedFeedback');
	}

	if (isset($_REQUEST['redirect_to']) && $_REQUEST['redirect_to'] == 'admin') {
		$redirect_to = 'admin';
	} else {
		$redirect_to = '';
	}

	GFUrl::redirect(GFUrl::getUrl()->projectURL($project,'','docman',$redirect_to),array('subdir'=>$df->getDocmanFolder()->getDocmanFolderId(),'feedback'=>$feedback));

} catch (InvalidDataException $ex) {
	$errors=$ex->getErrors();
 	$feedback = implode('<br />',$errors);
	include('DocmanFileVersionAdd.php');
}
?>
