<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id$
 * @author Tim Perdue tim@gforge.org
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */
require_once('lib/html/ProjectTemplate.php');
require_once('lib/plugin/PluginResult.php');

class FrsTemplate extends ProjectTemplate {

	/**
	 * Header - this subclasses header and just passes params and data that is specific
	 * to this template
	 * @param array array of parameters
	 */
	function header($params) {
		$params['selectedbottomtab']='frs';
		$Lang = Session::getSession()->getLanguage();
		if (isset($params['title'])) {
			$params['title']=' '.$Lang->getText('Frs.TabString').' > '.$params['title'];
		} else {
			Throw new exception('Missing title in frs template');
		}
		
		if(isset($params['frspackage']) && !isset($params['frsadmin'])) {
			$this->addBreadCrumb('<a href="'.GFUrl::getUrl()->projectUrl($params['project'],'FrsReleaseBrowse','frs','',array('frs_package_id'=>$params['frspackage']->getId())).'">'.$params['frspackage']->getPackageName().'</a>');			
		}
		
		$this->addBreadCrumb('<a href="'.GFUrl::getUrl()->projectUrl($params['project'],'index','frs').'">'.$Lang->getText('Frs.TabString').'</a>');	
		return parent::header($params);
	}

	/**
	 *      getPluginNavElements - this overrides parent class and adds its own
	 *      plugin listener
	 *      @return PluginResultSet
	 */
	function getPluginNavElements($params) {
		$prs = parent::getPluginNavElements($params);
		$tprs = ActionManager::Notify('GET_FRS_NAV_ELEMENTS',null);
		foreach ($tprs as $pr) {
			$prs->addResult($pr);
		}
		return $prs;
	}
	
	/**
	 * getTemplateNavElements - this function can be overridden
	 * by subclasses so you can add navigation entries
	 * @return array - complex array of data.
	 */
	function getTemplateNavElements($params) {
		$url = GFurl::getUrl();
		$lang = Session::getSession()->getLanguage();
		$user = Session::getSession()->getUser();
		$loggedin = Session::getSession()->isLoggedIn();
		$project = $params['project'];

		$pine = $this->getPluginNavElements($params);
		$ret = array();
		foreach ($pine as $result) {
			$ret[]=$result->getResult();
		}
		
		$elements = array();
		
		/*if (isset($params['frspackage'])) {
			$package = $params['frspackage'];*/
		
		$crit = new Criteria();
		$crit->add(FrsPackagePeer::PROJECT_ID, $project->getId());
		$crit->addAscendingOrderByColumn(FrsPackagePeer::PACKAGE_NAME);
		
		$packages = FrsPackagePeer::doSelect($crit);
				
		foreach($packages as $package) {
			$subelements = array();
			if($loggedin && $package->userCanRead()) {
				
				if($package->userIsAdmin()) {
					$subelements[] = array('link' => $url->projectUrl($project, 'FrsPackageEdit', 'frs', 'admin', array('frs_package_id'=>$package->getId())),
					'description' => $lang->getText('Tabs.Admin'));
				}
		
				$subelements[] = array('link' => $url->projectUrl($project, 'FrsReleaseBrowse', 'frs', '', array('frs_package_id'=>$package->getId())),
					'description' => $lang->getText('FrsPackage.BrowsePageTitle'));
				
				if ($package->userIsMonitoring($user)) {
					$subelements[] = array('link' => $url->getMonitorUrl(FrsPackage::SECTION, $package->getPrimaryKey(), null, false),
					'description' => $lang->getText('FrsPackage.StopMonitor'));
				} else {
					$subelements[] = array('link' => $url->getMonitorUrl(FrsPackage::SECTION, $package->getPrimaryKey(), null, true),
					'description' => $lang->getText('FrsPackage.Monitor'));
				}
				
				$subelements[] = array('link' => GFUrl::getUrl()->projectURL($project,'UsersMonitoringBrowse','','usersmonitoring',array('section'=>FrsPackage::SECTION,'ref_id'=>$package->getPrimaryKey(),'description'=>$package->getPackageName(),'type'=>'item','return_to'=>$_SERVER['REQUEST_URI'])),
						'description' => $lang->getText('Monitor.UsersMonitoringItem'));

				if(isset($params['frspackage']) && $params['frspackage']->getId()==$package->getId()) {
					$expanded=true;
				}
				else {
					$expanded=false;
				}
				
				$elements[] = array('link'=>'',
				'description'=> $package->getPackageName(),
				'expandables' => $subelements,
				'expanded'=>$expanded);
			}
		}
		
		if ($loggedin) {
			if ($project->getPermission()->check(FrsPlugin::SECTION,0,FrsPlugin::WRITE)) {
				$elements[] = array('link' => $url->projectURL($project,'','frs','admin', ''),
					'description' => $lang->getText('Tabs.Admin'));
			}
		}
		
		if (count($elements) > 0) {
			$ret[] = array(
				'title' => $lang->getText('Frs.TabString'),
				'elements'=> $elements
			);
		}
		


		return $ret;
	}


}

?>
