<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id: Layout.php 270 2005-12-31 03:02:47Z tperdue $
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */
//
// This code edits a FrsRelease and saves it to the 
// database
//
require_once('plugins/frs/lib/FrsRelease.php');
require_once('Validator.php');
require_once('exceptions/PermissionDeniedException.php');
require_once('core/Language.php');
require_once('lib/core/Filesystem.php');
require_once('lib/core/TroveLink.php');

if ($_SERVER['REQUEST_METHOD'] != 'POST') {
	throw new PermissionDeniedException();
}

$Project = GFUrl::getUrl()->getProject();
$FrsRelease = FrsReleasePeer::retrieveByPk($_REQUEST['frs_release_id']);
$FrsPackage = $FrsRelease->getFrsPackage();
if (!is_object($FrsPackage) || !$FrsPackage->userIsAdmin()
	|| $FrsPackage->getProject()->getProjectId() != $Project->getProjectId()) {
	throw new PermissionDeniedException();
}

$errors = array();
$Lang = Language::getSessLang();
$sess=Session::getSession();



//
// TODO Validate the values passed by $_POST. Store the errors in $error like
// $errors["field_name"] = error_description
//

if (count($errors) == 0) {
//	$FrsRelease->setFrsPackageId( Validator::sanitizeInt($_POST['frs_package_id']) );
	//names are sanitized internally
	$FrsRelease->setReleaseName( $_POST['release_name'] );
	$FrsRelease->setReleaseNotes( Validator::sanitizeString($_POST['release_notes']) );
	$FrsRelease->setChanges( Validator::sanitizeString($_POST['changes']) );
	if(array_key_exists('status_id',$_POST)) {
		$visible = FrsRelease::STATUS_ACTIVE;
	} else {
		$visible = FrsRelease::STATUS_HIDDEN;
	}
	$FrsRelease->setStatusId( Validator::sanitizeInt($visible) );
	if (array_key_exists('preformatted',$_POST)) {
		$preformatted = 1;
	} else {
		$preformatted = 0;
	}
	if (isset($_REQUEST['is_released']) && Validator::sanitizeInt($_REQUEST['is_released']) == 1) {
		$FrsRelease->setIsReleased(true);
	} else {
		$FrsRelease->setIsReleased(false);
	}

	$FrsRelease->setPreformatted( Validator::sanitizeInt($preformatted) );
	$FrsRelease->setReleaseDate( Validator::sanitizeDate($_POST['release_date']) );
//	$FrsRelease->setReleasedBy( Validator::sanitizeInt($_POST['released_by']) );
	if (isset($_POST['deletefile']) && is_array($_POST['deletefile'])) {
		foreach ($_POST['deletefile'] as $file_id) {
			$fs = FilesystemPeer::retrieveByPK($file_id); //doSelect($c);

			if (!is_object($fs) 
				|| $fs->getSection() != FrsRelease::SECTION 
				|| $fs->getRefId() != $FrsRelease->getFrsReleaseId()) {
				echo "Invalid File Delete";
			} else {
				// Audit trail
				$audit = new AuditTrail();
				$audit->setUser(Session::getSession()->getUser());
				$audit->setSection(Project::SECTION);
				$audit->setRefId($Project->getProjectId());
				$audit->setFieldName('frsfile');
				$audit->setNewValue('_deleted_');
				$audit->setOldValue($fs->getFileName());
				$audit->save();
				
				
				$fs->delete();
			}
		}
	}

	try {
		//
		//      handle the files
		//

		$isUploadEnable = GFConf::get('system.ftp_upload');
		if ($isUploadEnable){
			
			$prUnixName = $Project->getUnixName();
			$path = GFConf::get('system.ftp_upload_dir');
			$fullpath = $path.$prUnixName;

			if (isset($_POST['files'])) {
				$filename_id = $_POST['files'];
				$frs_files = $_POST['frs_files'];
				$filename = $frs_files[$filename_id];

				if ($filename !== 'None'){
					$size=filesize($fullpath."/".$filename);
					$type=mime_content_type($fullpath."/".$filename);	
				
					$fs = new Filesystem();
					$fs->setSection(FrsRelease::SECTION);
					$fs->setRefId($FrsRelease->getFrsReleaseId());

					$fs->setFileName( $filename );
					$fs->setFileType( $type );
					$fs->setFileSize( $size );
					$fs->setPostedBy( $sess->getUser()->getUserId() );
					$fs->save();
					$fs->setFileDataFromFTP($fullpath."/".$filename);
					unlink($fullpath."/".$filename);
				}
			}
		}

		for ($i=0; $i<5; $i++) {
			$error=$_FILES['addfile']['error'][$i];
			$filename=$_FILES['addfile']['name'][$i];
			
			if ($error > 0 && $error != 4) {
				$fileerrors = StringUtils::getFileUploadErrorString($error, $filename);
				throw new InvalidDataException($fileerrors);
				continue;
			}

			$tmp_name=$_FILES['addfile']['tmp_name'][$i];
			if (!is_uploaded_file($tmp_name)) {
				continue;
			}
			$size=$_FILES['addfile']['size'][$i];
			$type=$_FILES['addfile']['type'][$i];
			
			$FrsRelease->releaseFile($tmp_name, $filename, $type, $size);
		}

	
		$FrsRelease->save();
	
	
		//trove
		if (array_key_exists('trove_devstatus',$_POST)) {
			$crit = new Criteria();
			$crit->add(TroveLinkPeer::SECTION, FrsRelease::SECTION);
			$crit->add(TroveLinkPeer::REF_ID, $FrsRelease->getFrsReleaseId());
			TroveLinkPeer::doDelete($crit);
			$troveLink = new TroveLink();
			$troveLink->setSection(FrsRelease::SECTION);
			$troveLink->setRefId($FrsRelease->getFrsReleaseId());
			$troveLink->setTroveCategoryId($_POST['trove_devstatus']);
			$troveLink->save();		
		}

		$url = GFUrl::getUrl();
		GFUrl::redirect($url->currentBaseURL('FrsReleaseBrowse'), array('feedback' => $Lang->getText('FrsRelease.EditFeedback'),'frs_package_id'=>$FrsPackage->getFrsPackageId()));

	} catch (InvalidDataException $ex) {
		$errors = array_merge($errors, $ex->getErrors());		
		$feedback = implode('<br />', $errors);
		include('FrsReleaseEdit.php');
	}
} else {
	$feedback = implode('<br />', $errors);
	include('FrsReleaseEdit.php');
}

?>
