<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id: index.php 620 2006-03-23 16:13:34Z tperdue $
 * @author Tim Perdue tim@gforge.org
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

require_once('plugins/scm/lib/ScmCommit.php');
require_once('plugins/scm/lib/ScmCommitFile.php');
require_once('plugins/scm/lib/SCMRepositoryFactory.php');
require_once('plugins/scm/lib/RepositoryBrowser.php');
require_once('lib/html/association.php');

/**
 * This script is included by the specific SCM plugins in order to display info about
 * a commit
 */
if (!isset($_GET['scm_commit_id']) || empty($_GET['scm_commit_id'])) {
	throw new PermissionDeniedException();
}
$scm_commit_id = $_GET['scm_commit_id'];

// $template and $params must be set by the including script
$template->header($params);

$scm_commit = ScmCommitPeer::retrieveByPk($scm_commit_id);
if (is_null($scm_commit) || $scm_commit->getProjectId() != $project->getProjectId()) {
	throw new Exception($lang->getText('ScmCommit.InvalidScmCommitId', array($scm_commit_id)));
}

$files = $scm_commit->getScmCommitFiles();
$user = $scm_commit->getUser();
$project = $scm_commit->getProject();

$repository = SCMRepositoryFactory::getRepository($project);
$browser = new RepositoryBrowser($repository);
?>
<p>
<h3><?php echo $lang->getText('ScmCommit.DetailsTitle', array($scm_commit_id)) ?></h3>
</p>
<p>
<strong><?php echo $lang->getText('ScmCommit.CommittedByTitle') ?>:</strong>
	<a href="<?php echo GFUrl::getUrl()->userUrl($user); ?>"><?php echo $user->getFullName() ?></a><br />
<strong><?php echo $lang->getText('ScmCommit.DateTitle') ?>:</strong> <?php echo $scm_commit->getCommitDate() ?><br />
<strong><?php echo $lang->getText('ScmCommit.CommitLogTitle') ?>:</strong> <br />
<?php
	// This small hack allows to link to the proper tracker item (if any)
	$log = $scm_commit->getMessageLog();
	preg_match_all('/\\[#(\d+)\\]/', $log, $matches);
	
	if (count($matches) > 1) {
		$tracker_item_ids = $matches[1];
		foreach ($tracker_item_ids as $tracker_item_id) {
			$c = new Criteria();
			$c->add(TrackerItemPeer::TRACKER_ITEM_ID, $tracker_item_id);
			$c->addJoin(TrackerItemPeer::TRACKER_ID, TrackerPeer::TRACKER_ID);
			$c->add(TrackerPeer::PROJECT_ID, $project->getProjectId());
			$tracker_item = TrackerItemPeer::doSelectOne($c);
			if (!is_null($tracker_item)) {
				$link = GFUrl::getUrl()->projectUrl($project, 'TrackerItemEdit', 'tracker', '', array('tracker_item_id' => $tracker_item_id));
				$log = preg_replace('/\\[#'.$tracker_item_id.'\\]/', '<a href="'.$link.'">[#'.$tracker_item_id.']</a>', $log);
			}
		}
	}
	echo nl2br($log);
?>
</p>
<div class="tabber">
<?php echo '<div class="tabbertab'. ((isset($_GET['selectedtab']) && $_GET['selectedtab']=='files') ? ' tabbertabdefault' : '') .'" title="'. $lang->getText('ScmCommit.FilesTitle') . '" id="filestab">';
		$theader = array();
		$theader[] = $lang->getText('ScmCommitFile.FileTitle');
		$theader[] = $lang->getText('ScmCommitFile.PrevVersionTitle');
		$theader[] = $lang->getText('ScmCommitFile.NewVersionTitle');
		$theader[] = $lang->getText('ScmCommitFile.DiffTitle');
		echo $template->tableTop($theader);
		
		foreach ($files as $file) {
			$trow = array();
			$trow[] = '<a href="'.$browser->getBrowsePathUrl($file).'">'.$file->getModifiedFile().'</a>';
			$trow[] = $file->getPrevVersion();
			$trow[] = $file->getNewVersion();
			if (!(intval($file->getPrevVersion()) == 0)) {
				$trow[] = '<a href="'.$browser->getDiffUrl($file->getModifiedFile(), $file->getPrevVersion(), $file->getNewVersion()).'">'.$lang->getText('ScmCommitFile.DiffText').'</a>';
			} else {
				$trow[] = "-";
			}
			echo $template->tableRow($trow);
		}
		
		echo $template->tableBottom();
	?>
</div>

<? if($project->usesPlugin(Tracker::SECTION)){ ?>
<div class="tabbertab<?php echo ((isset($_GET['selectedtab']) && $_GET['selectedtab'] == 'relatedtrackeritem') ? ' tabbertabdefaul' : ''); ?>" title="<?php echo $lang->getText('ScmCommit.RelatedTrackerItems') ?>" id="relatedtrackeritemtab">
	<?php
		$theader = array();
		$theader[] = $lang->getText('TrackerItem.TrackerItemIdName');
		$theader[] = $lang->getText('Tracker.TrackerNameName');
		$theader[] = $lang->getText('TrackerItem.SummaryName');
		$tis = $scm_commit->getTrackerItems();
		echo $template->tableTop($theader);
		if(count($tis) > 0){
			foreach($tis as $ti){
				$trow = array();
				$trow[] = $ti->getTrackerItemId();
				$trow[] = '<a href="' . GFUrl::getUrl()->ProjectUrl($project,'TrackerItemBrowse', 'tracker', '', array('tracker_id'=>$ti->getTracker()->getTrackerId())) . '">' . $ti->getTracker()->getTrackerName() .'</a>';
				$trow[] = '<a href="' . GFUrl::getUrl()->ProjectUrl($project,'TrackerItemEdit','tracker', '',array('tracker_item_id'=>$ti->getTrackerItemId())) .'">'. $ti->getSummary() . '</a>';

				echo $template->tableRow($trow);
			}
		} else {
			echo $template->tableFullRow($lang->getText('TrackerItem.NoneFound'));
		}
		echo $template->tableBottom();
	?>

</div>
<?php }
/* Disabled in ce
?>

<div class="tabbertab<?php echo ((isset($_GET['selectedtab']) && $_GET['selectedtab']=='associations') ? ' tabbertabdefault' : ''); ?>" title="<?php echo $lang->getText('Associations') ?>" id="associationstab">
<?php echo renderAssociationList(ScmCommit::SECTION,$scm_commit_id,$project->userIsAdmin(),$template,$project); ?>
</div>
<?php
*/
$settings = null;
if(!$settings || $settings->getShowTagsTab()){
?>
<div class="tabbertab<?php echo ((isset($_GET['selectedtab']) && $_GET['selectedtab']=='tags') ? ' tabbertabdefault' : ''); ?>" title="<?php echo $lang->getText('Tag.TabHeader') ?>" id="tagstab">
<?php 
echo TagsRenderer::getTagsTable($scm_commit_id,ScmCommit::SECTION, $theme);

?>
<?php } ?>


</div>
<?php
$template->footer($params);
?>
