#!/usr/bin/php
<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id$
 * @author Marcelo Mottalli <marcelo@gforgegroup.com>
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

require_once('initialize.php');
require_once('GFConf.php');
require_once('core/Project.php');
require_once('core/User.php');
require_once('core/Language.php');
require_once('exceptions/InvalidProjectException.php');
require_once('plugins/scm/lib/ScmCommit.php');
require_once('plugins/scm/lib/ScmCommitWrapper.php');
require_once('plugins/scmperforce/lib/PerforceConfigFile.php');
require_once('plugins/scmperforce/lib/PerforceManager.php');
require_once('plugins/scmperforce/lib/PerforceRepository.php');

if ($argc != 4) {
	echo "Usage: ".$argv[0]." <project> <changelist number> <user>\n";
	exit(1);
}

$project_name = $argv[1];
$changelist_num = $argv[2];
$username = $argv[3];

// Start the session as the user that's committing
$user = UserPeer::retrieveByUnixName($username);
if (is_null($user)) {
	echo 'Invalid user name: '.$username."\n";
	exit(1);
}
Session::getSession()->setUser($user);

$project = ProjectPeer::retrieveByUnixName($project_name);
if (!is_object($project)) {
	throw new InvalidProjectException($project_name);
}

$repos = new PerforceRepository($project);
$manager = new PerforceManager();
$changelist_data = $manager->getChangelistData($changelist_num);

// See if we must check for a tracker item ID in the message log
$preferences = ScmPreferencePeer::retrieveByPk($project->getProjectId());
if (!is_null($preferences) && $preferences->getRequireTrackerItemId()) {
	$log = $changelist_data['log'];

	$invalid_ids = array();
	if (!ScmCommit::checkTrackerItemIds($log, $project, $invalid_ids)) {
		if (count($invalid_ids)>0) {
			echo "\n".'The following Tracker Item Ids are not valid for this Project or you are violating commit rules:'."\n";
			echo '[#'.implode(']\n[#', $invalid_ids)."]\n";
		} else {
			echo "\n".'Commit not related to any Tracker Item.'."\n";
		}
		echo "\n".'Please specify one or more valid Tracker Item Ids in the commit'."\n";
		echo 'log as "[#nnnn]". Edit the description with the command "p4 changelist '.$changelist_num.'".'."\n";
		echo 'and then submit the changes with the command "p4 submit -c '.$changelist_num.'".'."\n";
		exit(1);
	}
}

// Now see if the user has permissions to commit to every path that was changed
$disallowed_paths = array();
if (array_key_exists($repos->getRepositoryName(), $changelist_data['changes'])) {
	foreach ($changelist_data['changes'][$repos->getRepositoryName()] as $file) {
		$dir = dirname($file['path']);
		if (!$repos->userCanCommit($dir) && !in_array($dir, $disallowed_paths)) {
			$disallowed_paths[] = $dir;
		}
	}
}

if (count($disallowed_paths) > 0) {
	// User can't commit to some directories / modules
	echo "\n".'You don\'t have permissions to commit to the following directories:';
	echo "\n* ".implode("\n* ", $disallowed_paths)."\n";
	
	exit(1);
}

exit(0);
?>
