<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id: Layout.php 270 2005-12-31 03:02:47Z tperdue $
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */
//
// This code edits a TrackerItem and saves it to the 
// database
//
require_once('plugins/tracker/lib/TrackerItem.php');
require_once('Validator.php');
require_once('exceptions/PermissionDeniedException.php');
require_once('core/Language.php');
require_once('core/FilesystemPeer.php');
require_once('plugins/tracker/lib/TrackerItemTime.php');
require_once('plugins/tracker/lib/TrackerItemRelation.php');
require_once('plugins/tracker/lib/TrackerItemDuplicate.php');
require_once('plugins/tracker/lib/TrackerItemMessage.php');

if ($_SERVER['REQUEST_METHOD'] != 'POST') {
	throw new PermissionDeniedException();
}

//force login
$sess = Session::getSession();
if (!$sess->isLoggedIn()) {
	throw new NotLoggedInException();
}
$tracker_item_id = (isset($_REQUEST['tracker_item_id'])) ? intval($_REQUEST['tracker_item_id']) : 0;
$start = (isset($_REQUEST['start'])) ? intval($_REQUEST['start']) : 0;
$Project = GFUrl::getUrl()->getProject();

$TrackerItem = TrackerItemPeer::retrieveByPk($tracker_item_id);
if (!$TrackerItem || !is_object($TrackerItem)) {
	throw new Exception('No Such Item');
}
$Tracker=$TrackerItem->getTracker();
//validate that this is a legitimate trackeritem for this tracker and user can add items
if (!$TrackerItem || !is_object($TrackerItem) || $Tracker->getProject()->getProjectId() != $Project->getProjectId()) {
	throw new PermissionDeniedException();
}

// Make sure the tracker belongs to the current project
if ($Tracker->getProjectId() != $Project->getProjectId()) {
	throw new PermissionDeniedException();
}


//
//	Determine level of permission they have
//
$ADMIN=$Project->getPermission()->check(Tracker::SECTION, $Tracker->getTrackerId(), Tracker::PERMLEVEL_ADMIN);
$TECHONLY=!$ADMIN && $Project->getPermission()->check(Tracker::SECTION, $Tracker->getTrackerId(), Tracker::PERMLEVEL_TECH);
$SUBMITTERONLY= !$ADMIN && !$TECHONLY && ($sess->getUser()->getUserId() == $TrackerItem->getSubmittedBy());
$READONLY=!$ADMIN && !$TECHONLY && !$SUBMITTERONLY && $TrackerItem->userCanRead();

if (!$READONLY && !$ADMIN && !$TECHONLY && !$SUBMITTERONLY) {
	throw new PermissionDeniedException();
}


$errors = array();
$language = Language::getSessLang();

//
// TODO Validate the values passed by $_POST. Store the errors in $error like
// $errors["field_name"] = error_description
//

try {
	$con = Propel::getConnection(TrackerItemPeer::DATABASE_NAME);
	$con->begin();

	if (isset($_POST['deletefile']) && is_array($_POST['deletefile'])) {
		foreach ($_POST['deletefile'] as $file_id) {
			$TrackerItem->deleteAttachment($file_id);
		}
	}

	//
	//	Add message
	//
	if (isset($_POST['body']) && strlen($_POST['body']) > 0) {
		$tim = new TrackerItemMessage();
		//$TrackerItem->addTrackerItemMessage($tim);
		$tim->setTrackerItemId($TrackerItem->getTrackerItemId());
		$tim->setBody(Validator::sanitizeString($_POST['body']));
		$tim->setSubmittedBy( $sess->getUser()->getUserId() );
		$tim->save();
	}
	if ($READONLY) {
		//can't do anything except add message. Quit here
		$TrackerItem->unprivilegedSave();
		$con->commit();
		GFUrl::getUrl()->redirect(GFUrl::getUrl()->currentBaseURL('TrackerItemBrowse', array('feedback' => $language->getText('TrackerItem.EditFeedback'),'tracker_id'=>$Tracker->getTrackerId())));
		exit;
	}
	//
	//	handle the files
	//
	for ($i=0; $i<5; $i++) {
		$error=$_FILES['addfile']['error'][$i];
		$filename=$_FILES['addfile']['name'][$i];

		if ($error > 0 && $error != 4) {
			$fileerrors = StringUtils::getFileUploadErrorString($error, $filename);
			throw new InvalidDataException($fileerrors);
			continue;
		}
		

		$tmp_name=$_FILES['addfile']['tmp_name'][$i];
		if (!is_uploaded_file($tmp_name)) {
			continue;
		}
		$size=$_FILES['addfile']['size'][$i];
		$type=$_FILES['addfile']['type'][$i];
		$fs = new Filesystem();
		$fs->setSection(TrackerItem::SECTION);
		$fs->setRefId($TrackerItem->getTrackerItemId());

		$fs->setFileName( $filename );
		//$fs->setFileNameSafe();
		$fs->setFileType( $type );
		$fs->setFileSize( $size );
		$fs->setPostedBy( $sess->getUser()->getUserId() );
//TODO audit trail
		$fs->save();
		$fs->setFileDataFromPath( $tmp_name );
	}
	if ($SUBMITTERONLY) {
		//can't do anything except add message and add files
		$TrackerItem->unprivilegedSave();
		$con->commit();
		GFUrl::getUrl()->redirect(GFUrl::getUrl()->currentBaseURL('TrackerItemBrowse', array('feedback' => $language->getText('TrackerItem.EditFeedback'),'tracker_id'=>$Tracker->getTrackerId())));
		exit;
	}

	//$TrackerItem->setTrackerId( Validator::sanitizeInt($_POST['tracker_id']) );
	//$TrackerItem->setStatusId( Validator::sanitizeInt($_POST['status_id']) );
	$TrackerItem->setPriority( Validator::sanitizeInt($_POST['priority']) );
	//$TrackerItem->setSubmittedBy( Validator::sanitizeInt($_POST['submitted_by']) );
	//$TrackerItem->setOpenDate( Validator::sanitizeDate($_POST['open_date']) );
	//$TrackerItem->setCloseDate( Validator::sanitizeDate($_POST['close_date']) );
	if ($Tracker->getDatatype()==Tracker::DATATYPE_TASK) {
		if (isset($_POST['start_date']) && strlen($_POST['start_date']) > 5) {
			$TrackerItem->setOpenDate( Validator::sanitizeDate($_POST['start_date']) );
		}
		if (isset($_POST['end_date']) && strlen($_POST['end_date']) > 5) {
			$TrackerItem->setCloseDate( Validator::sanitizeDate($_POST['end_date']) );
		}
	}
	$TrackerItem->setSummary( Validator::sanitizeString($_POST['summary']) );
	$TrackerItem->setLastModifiedDate(time());
	$TrackerItem->setLastModifiedBy($sess->getUser()->getUserId());
	if(isset($_POST['details'])) {
		$TrackerItem->setDetails( Validator::sanitizeString($_POST['details']) );
	}
	if (!isset($_POST['assigned_to'])) {
		$assigned_to=array('100');
	} else {
		$assigned_to=$_POST['assigned_to'];
		// Remove nobody user if set and its not the only user assigned.
		$remove_assigned_to = array_search(100, $assigned_to);
		if ($remove_assigned_to!==false && count($assigned_to)>1) {
			array_splice($assigned_to, $remove_assigned_to, 1);
		}
	}
	$TrackerItem->updateAssignees($assigned_to);
	if (array_key_exists('extra_field',$_POST)) {
		$TrackerItem->updateExtraFields($_POST['extra_field']);
	}

	if (isset($_REQUEST['related_items']) && !empty($_REQUEST['related_items'])) {
		$rels=explode(',',$_REQUEST['related_items']);
		$parsed_rels = array();
		for ($i=0; $i < count($rels); $i++) {
			$id = intval($rels[$i]);
			if (!$id) continue;
			$parsed_rels[] = $id;
		}
		$TrackerItem->addRelations($parsed_rels);
	}
	if (isset($_REQUEST['del_relation']) && !empty($_REQUEST['del_relation'])) {
		$TrackerItem->deleteRelations($_REQUEST['del_relation']);
	}
	if (isset($_REQUEST['duplicate_items']) && !empty($_REQUEST['duplicate_items'])) {
		$dups=explode(',',$_REQUEST['duplicate_items']);
		$parsed_dups = array();
		for ($i=0; $i < count($dups); $i++) {
			$id = intval($dups[$i]);
			if (!$id) continue;
			$parsed_dups[] = $id;
		}
		$TrackerItem->addDuplicates($parsed_dups);
	}
	if (isset($_REQUEST['del_duplicate']) && !empty($_REQUEST['del_duplicate'])) {
		$TrackerItem->deleteDuplicates($_REQUEST['del_duplicate']);
	}
	ActionManager::notify('TRACKER_ITEM_EDIT_ACTION',$TrackerItem);



	//time entry
	if (isset($_POST['hours']) && !empty($_POST['hours'])) {
		$tit=new TrackerItemTime();
		$TrackerItem->addTrackerItemTime($tit);
		$tit->setHours( floatval($_POST['hours']));
		$tit->setTrackerTimeCodeId( Validator::sanitizeInt($_POST['tracker_time_code_id']));
		$tit->setDateEntry( Validator::sanitizeDate($_POST['date_entry']));
		$tit->setUser( $sess->getUser() );
	}
	$TrackerItem->save();

	$con->commit();

	GFUrl::getUrl()->redirect(GFUrl::getUrl()->currentBaseURL('TrackerItemBrowse', array('feedback' => $language->getText('TrackerItem.EditFeedback'),'tracker_id'=>$Tracker->getTrackerId(),'start'=>$start)));
} catch (InvalidDataException $ex) {
	$con->rollback();
	$feedback = '* '.implode('<br />* ', $ex->getErrors());
	include('TrackerItemEdit.php');
	//GFUrl::getUrl()->redirect(GFUrl::getUrl()->currentBaseURL('TrackerItemEdit', array('feedback' => $feedback,'tracker_id'=>$Tracker->getTrackerId(), 'tracker_item_id'=>$tracker_item_id)));
}

?>
