<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id$
 * @author Daniel Perez daniel@gforgroup.com
 * @date 2006-02-27
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

require_once ('plugins/userwiki/lib/om/BaseWikiPage.php');
require_once("plugin/ActionManager.php");
require_once ('plugins/userwiki/lib/WikiVersionPeer.php');
require_once ('lib/core/Filesystem.php');
require_once ('lib/core/FilesystemPeer.php');
require_once('plugins/userwiki/lib/UserwikiPlugin.php');

/** 
 * The skeleton for this class was autogenerated by Propel  * You should add additional methods to this class to meet the
 * application requirements.  This class will only be generated as
 * long as it does not already exist in the output directory.
 *
 * @package plugins.wiki.lib 
 */
class UserWikiPage extends BaseUserWikiPage {
	/**
	 * Stores the object in the database using the Propel methods. Informs the plugin manager.
	 * This method was added by propel_customizer.php.
	 *
	 * @param Connection $con
	 * @return void
	 * @throws PropelException
	 */
	function save($con = null) {
		parent::save($con);
		ActionManager::notify("WIKI_PAGE_SAVE", $this);
	}

	
	protected $latest_version;
	protected $version;
	protected $previous_version; // previous existing version from latest, or null if theres not
	CONST FLAGS_LOCKED = 1;
	CONST FLAGS_UNLOCKED = 0;

	
	/**
	 * Inits the latest version object
	 *
	 */
	private function initLatestVersion() {
		$con = Propel::getConnection(UserWikiPagePeer::DATABASE_NAME);
		$sql = 'select * from wiki_version where wiki_page_id=\'' . $this->getPrimaryKey() . '\' and page_version = (select max(page_version) from wiki_version where wiki_page_id=\'' . $this->getPrimaryKey() . '\')'; // get highest version
		$stmt = $con->createStatement();
		$rs = $stmt->executeQuery($sql, ResultSet::FETCHMODE_NUM);
		$this->latest_version = new UserWikiVersion();
		$rs->next();
		$this->latest_version->hydrate($rs);
	}
	
	/**
	 * Inits the previous version object
	 *
	 */
	private function initPreviousVersion() {
		$this->previous_version = null; // by default its null, so we dont have a previous version
		// get all the versions previous to the latest one and see which is first
		$c = new Criteria();
		$c->add(UserWikiVersionPeer::WIKI_PAGE_ID,$this->getPrimaryKey());
		$c->addDescendingOrderByColumn(UserWikiVersionPeer::PAGE_VERSION);
		$versions = UserWikiVersionPeer::doSelect($c);
		if (count($versions)>1) { // more than 2 versions
			$this->previous_version = $versions[1];
		}
	}	
	
	/**
	 * Inits the version object of the version passed as parameter
	 *
	 * @param int version -> page_version
	 * 
	 */
	private function initVersion($version) {
		$con = Propel::getConnection(UserWikiPagePeer::DATABASE_NAME);
		$sql = 'select * from wiki_version where wiki_page_id=\'' . $this->getPrimaryKey() . '\' and page_version = \''. $version . "'"; // get the version
		$stmt = $con->createStatement();
		$rs = $stmt->executeQuery($sql, ResultSet::FETCHMODE_NUM);
		if ($rs->getRecordCount()!=1) {
			$this->version = null; // something happened, version may not exist
		} else {
			$this->version = new UserWikiVersion();
			$rs->next();
			$this->version->hydrate($rs);
		}
	}	
	
	/**
	 * Fetchs the latest version contents and returns it
	 *
	 * @return string	contents
	 */
	public function getLatestContents() {
		if (!is_object($this->latest_version)) { // fetch the latest version if not set
			$this->initLatestVersion();
		}
		$filesystem_id = $this->latest_version->getPrimaryKey();
		$c = new Criteria();
		$c->add(FilesystemPeer::REF_ID,$filesystem_id);
		$c->add(FilesystemPeer::SECTION,UserwikiPlugin::SECTION);
		$fso = FilesystemPeer::doSelectOne($c);
		if (is_object($fso)) {
			return $fso->getFileData(false);
		} else {
			return null;
		}
	}
	
	/**
	 * Fetchs the version contents 
	 *
	 * @param int $version (page_version)
	 * @return string	contents
	 */
	public function getContents($version) {
		if ($version!=null) {
			$ver = $this->getVersion($version);
			if (is_object($ver)) {
				$filesystem_id = $this->version->getPrimaryKey();
				$c = new Criteria();
				$c->add(FilesystemPeer::REF_ID,$filesystem_id);
				$c->add(FilesystemPeer::SECTION,UserwikiPlugin::SECTION);
				$fso = FilesystemPeer::doSelectOne($c);
				if (is_object($fso)) {
					return $fso->getFileData(false);				
				} else {
					return null;
				}
			} else {
				return null;
			}
		} else {
			return null;
		}
	}
	
	/**
	 * Returns the version object corresponding to the latest version of the page
	 *
	 * @return version object
	 */
	public function getLatestVersion(){
		if (!is_object($this->latest_version)) { // fetch the latest version if not set
			$this->initLatestVersion();
		}
		return $this->latest_version;
	}

	/**
	 * Returns the version object corresponding to the previous version of the page or null
	 *
	 * @return version object
	 */
	public function getPreviousVersion(){
		if (!is_object($this->previous_version)) { // fetch the previous version if not set
			$this->initPreviousVersion();
		}
		return $this->previous_version;
	}	
	
	
	/**
	 * returns the version (if exists) from the version passed as a parameter
	 *
	 * @param int $version (page_version)
	 * @return version object if exists, null otherwise
	 */
	public function getVersion($version) {
		if ( (!is_object($this->version)) || ($this->version->getPageVersion()!=$version) ) { // fetch the version if not set
			$this->initVersion($version);
		}
		return $this->version;		
	}
	
	/**
	 * returns the type of file from the filesystem object.
	 * we have 2 types, text/html which is fckeditor edited pages (new) and text only, 
	 * which are pages ported from old gforge4 wiki
	 *
	 */
	public function getType() {
		$ver = $this->getLatestVersion(); // retrieve for latest version, dont think well need to edit old versions
		if (is_object($ver)) {
			$filesystem_id = $this->latest_version->getPrimaryKey();
			$c = new Criteria();
			$c->add(FilesystemPeer::REF_ID,$filesystem_id);
			$c->add(FilesystemPeer::SECTION,UserwikiPlugin::SECTION);
			$fso = FilesystemPeer::doSelectOne($c);
			if (is_object($fso)) {
				return $fso->getFileType();
			} else {
				return null;
			}
		} else {
			return null;
		}
	}
	
	/**
	 * increases the hit count by one to the version 
	 *
	 * @param int $version (page_version)
	 */
	public function increaseHitCount($version) {
		$ver = $this->getVersion($version);
		if ($ver instanceof UserWikiVersion) {
			$ver->setHits($ver->getHits()+1);
			$ver->save();
		}
	}
	
	/**
	 * Specifies if the current user can create an entry in the database for this object
	 *
	 * @return bool
	 * @todo Program the logic
	 */
	public function userCanCreate() {
		$sessuser = Session::getSession()->getUser();
		if ($this->getSection()=='user') {
			if ($sessuser instanceof User) {
				$user = UserPeer::retrieveByPk($this->getRefId());
				if (is_object($user)) {
					// the same user can create
					if ($user->getPrimaryKey() == $sessuser->getPrimaryKey()) {
						return true;
					}
				} else {
					return false;
				}
			}
		}		
		if ($this->userIsAdmin()) {
			return true;
		}
		return false;
	}

	/**
	 * If this person is an admin for this object
	 * @return boolean
	 */
	public function userIsAdmin() {
		$sessuser = Session::getSession()->getUser();
		if ($this->getSection()=='user') {
			if ($sessuser instanceof User) {
				$user = UserPeer::retrieveByPk($this->getRefId());
				if (is_object($user)) {
					// the same user can create
					if ($user->getPrimaryKey() == $sessuser->getPrimaryKey()) {
						return true;
					}
				}
			}
		}
		return false;
		/*
		//user has permission as admin
		if ($perm->check(UserwikiPlugin::SECTION, $ref_id, UserwikiPlugin::ADMIN)) { 
			return true;
		}*/
	}

	/**
	 * Specifies if the current user can update this object's entry in the database
	 *
	 * @return bool
	 * @todo Program the logic
	 */
	public function userCanUpdate() {
		return $this->userIsAdmin();
	}
	
	/**
	 * Specifies if the current user can delete this object's entry from the database
	 *
	 * @return bool
	 * @todo Program the logic
	 */
	public function userCanDelete() {
		return $this->userIsAdmin();
	}

	/**
	 * Specifies if the current user has permissions to access this object
	 *
	 * @return bool
	 * @todo Program the logic
	 */
	public function userCanRead() {
		// we need some logic for this
		if ($this->userIsAdmin()) {
			return true;
		}
		return true;
	}
	
	public function delete($con = null) {
		// get the versions and delete them
		$versions = $this->getWikiVersions();
		foreach ($versions as $version) {
			$version->delete();
		}
		parent::delete($con);
	}
	
	public function getAllVersions() {
		$c = new Criteria();
		$c->add(UserWikiVersionPeer::WIKI_PAGE_ID, $this->getPrimaryKey());
		$c->addDescendingOrderByColumn(UserWikiVersionPeer::WIKI_VERSION_ID);
		$versions = UserWikiVersionPeer::doSelect($c);
		return $versions;
	}
}

