<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id: Layout.php 270 2005-12-31 03:02:47Z tperdue $
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

// This code generates a SOAP API for handling Association

require_once('core/Association.php');
require_once('core/AssociationPeer.php');
require_once('Validator.php');

/* ******************************************************************** */
/*                                 DATA TYPES                           */
/* ******************************************************************** */
$server->wsdl->addComplexType(
	'Association',
	'complexType',
	'struct',
	'sequence',
	'',
	array(
		'section' => array('name'=>'section', 'type' => 'xsd:string'),
		'ref_id' => array('name'=>'ref_id', 'type' => 'xsd:int'),
		'to_section' => array('name'=>'to_section', 'type' => 'xsd:string'),
		'to_ref_id' => array('name'=>'to_ref_id', 'type' => 'xsd:int'),
		'comment' => array('name'=>'comment', 'type' => 'xsd:string'),
		'associated_item_description' => array('name'=>'associated_item_description', 'type' => 'xsd:string'),
		'associated_item_url' => array('name'=>'associated_item_url', 'type' => 'xsd:string'),
	)
);


$server->wsdl->addComplexType(
	'ArrayOfAssociation',
	'complexType',
	'array',
	'',
	'SOAP-ENC:Array',
	array(),
	array(array('ref' => 'SOAP-ENC:arrayType', 'wsdl:arrayType' => 'tns:Association[]')),
	'tns:Association'
);

/* ******************************************************************** */
/*                                 METHODS                              */
/* ******************************************************************** */

$server->register(
	'getAssociations',
	array(
		'sessionHash'	=> 'xsd:string',
		'section' => 'xsd:string',
		'ref_id' => 'xsd:int',
	), 
	array('getAssociations' => 'tns:ArrayOfAssociation'),
	$uri, 
	$uri.'#getAssociations',
	'rpc',
	'encoded'
);


/**
 * SOAP method to retrieve a list of Association
 * @param	$section	Filter by section
 * @param	$ref_id	Filter by ref_id
 */
function getAssociations($sessionHash, $section, $ref_id) {
	$ip = $_SERVER['REMOTE_ADDR'];
	Session::getSession()->setup($sessionHash, $ip);

	$sql="SELECT section as from_section, ref_id as from_ref_id, to_section, to_ref_id, to_section AS section,to_ref_id AS ref_id, comment
		FROM association WHERE 
		(section='".Validator::sanitizeString($section)."' AND ref_id='".Validator::sanitizeInt($ref_id)."')
		UNION SELECT section as from_section, ref_id as from_ref_id, to_section, to_ref_id, section AS section,ref_id AS ref_id, comment
		FROM association WHERE
		(to_section='".Validator::sanitizeString($section)."' AND to_ref_id='".Validator::sanitizeInt($ref_id)."')";
	$rs=Propel::getConnection()->createStatement()->executeQuery($sql,ResultSet::FETCHMODE_ASSOC);

/*
	0. section, 
	1. ref_id, 
	2. from_section		// 0
	3. from_ref_id		// 1
	4. to_section  		// 2
	5. to_ref_id			// 3
	6. comment				// 4
	7. associatedItemDescription 	// 5
	8. associatedItemURL					// 6
*/	

	$res = array();

	$arr=array();
	while($rs->next()) {
		$arr[]=array($rs->getString('section'), $rs->getInt('ref_id'),
								 $rs->getString('from_section'), $rs->getInt('from_ref_id'),
								 $rs->getString('to_section'), $rs->getInt('to_ref_id'),
								 $rs->getString('comment'));
	}
		
	$prs=ActionManager::notify('GET_ASSOCIATED_ITEM_INFO',$arr);
	foreach ($prs as $result) {
			$associationList = $result->getResult();
			foreach ($associationList as $association) {
				$res[] = AssociationToSOAP($association);	
			}
	}	
	
	return $res;
}



$server->register(
	'addAssociation',
	array(
		'sessionHash'	=> 'xsd:string',
		'section' => 'xsd:string',
		'ref_id' => 'xsd:int',
		'to_section' => 'xsd:string',
		'to_ref_id' => 'xsd:int',
		'comment' => 'xsd:string',
	), 
	array('addAssociation' => 'xsd:int'),
	$uri, 
	$uri.'#addAssociation',
	'rpc',
	'encoded'
);


/**
 * SOAP method to add a Association
 * @param	$section
 * @param	$ref_id
 * @param	$to_section
 * @param	$to_ref_id
 * @param	$comment
 */
function addAssociation($sessionHash, $section, $ref_id, $to_section, $to_ref_id, $comment) {
	$ip = $_SERVER['REMOTE_ADDR'];
	Session::getSession()->setup($sessionHash, $ip);

	$obj = new Association();
	
	$obj->setSection( Validator::sanitizeString($section) );
	$obj->setRefId( Validator::sanitizeInt($ref_id) );
	$obj->setToSection( Validator::sanitizeString($to_section) );
	$obj->setToRefId( Validator::sanitizeInt($to_ref_id) );
	$obj->setComment( Validator::sanitizeString($comment) );
	try {
		$obj->save();
		return 1;
	} catch (Exception $e) {
		return new soap_fault('', 'addAssociation','Permission Denied - Cannot add This Record',$e->getMessage());
	}
}


$server->register(
	'deleteAssociation',
	array(
		'sessionHash'	=> 'xsd:string',
		'section' => 'xsd:string',
		'ref_id' => 'xsd:int',
		'to_section' => 'xsd:string',
		'to_ref_id' => 'xsd:int',
	), 
	array('deleteAssociation' => 'xsd:int'),
	$uri, 
	$uri.'#deleteAssociation',
	'rpc',
	'encoded'
);

/**
 * SOAP method to delete a single Association
 * @param	$section
 * @param	$ref_id
 * @param	$to_section
 * @param	$to_ref_id
 */
function deleteAssociation($sessionHash, $section, $ref_id, $to_section, $to_ref_id) {
	$ip = $_SERVER['REMOTE_ADDR'];
	Session::getSession()->setup($sessionHash, $ip);

	$crit= new Criteria();
	$crit->add( AssociationPeer::SECTION,$section );
	$crit->add( AssociationPeer::REF_ID,$ref_id );
	$crit->add( AssociationPeer::TO_SECTION,$to_section );
	$crit->add( AssociationPeer::TO_REF_ID,$to_ref_id);
	$obj = AssociationPeer::doSelectOne($crit);

	if (is_null($obj)) {
		return new soap_fault('', 'deleteAssociation','Permission Denied - Cannot Delete This Record','Permission Denied - Cannot View This Record');
	}
	try {
		$obj->delete();
	} catch (Exception $e) {
		return new soap_fault('', 'deleteAssociation','Permission Denied - Cannot Delete This Record',$e->getMessage());
	}
	return 1;
}

function AssociationToSOAP(&$arr) {
	$ret = array();
	$ret['section'] = $arr[0];
	$ret['ref_id'] = $arr[1];
	$ret['to_section'] = $arr[2];
	$ret['to_ref_id'] = $arr[3];
	$ret['comment'] = $arr[4];
	$ret['associated_item_description'] = $arr[5];
	$ret['associated_item_url'] = $arr[6];
	return $ret;
}
?>
