<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id: Layout.php 270 2005-12-31 03:02:47Z tperdue $
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

// This code generates a SOAP API for handling ForumThread

require_once('plugins/forum/lib/ForumThread.php');
require_once('plugins/forum/lib/ForumThreadPeer.php');
require_once('Validator.php');

/* ******************************************************************** */
/*                                 DATA TYPES                           */
/* ******************************************************************** */
$server->wsdl->addComplexType(
	'ForumThread',
	'complexType',
	'struct',
	'sequence',
	'',
	array(
		'forum_thread_id' => array('name'=>'forum_thread_id', 'type' => 'xsd:int', 'nillable' => 'false'),
		'forum_id' => array('name'=>'forum_id', 'type' => 'xsd:int', 'nillable' => 'false'),
		'created_by' => array('name'=>'created_by', 'type' => 'xsd:int', 'nillable' => 'false'),
		'thread_name' => array('name'=>'thread_name', 'type' => 'xsd:string', 'nillable' => 'true'),
		'message_count' => array('name'=>'message_count', 'type' => 'xsd:int', 'nillable' => 'false'),
		'most_recent_date' => array('name'=>'most_recent_date', 'type' => 'xsd:string', 'nillable' => 'false'),
	)
);


$server->wsdl->addComplexType(
	'ArrayOfForumThread',
	'complexType',
	'array',
	'',
	'SOAP-ENC:Array',
	array(),
	array(array('ref' => 'SOAP-ENC:arrayType', 'wsdl:arrayType' => 'tns:ForumThread[]')),
	'tns:ForumThread'
);

/* ******************************************************************** */
/*                                 METHODS                              */
/* ******************************************************************** */

$server->register(
	'getForumThreads',
	array(
		'sessionHash'	=> 'xsd:string',
		'forum_id' => 'xsd:int',
		'created_by' => 'xsd:int',
		'thread_name' => 'xsd:string',
		'msg_count_min' => 'xsd:int',
		'msg_count_max' => 'xsd:int',
		'recent_date_min' => 'xsd:string',
		'recent_date_max' => 'xsd:string'
	), 
	array('getForumThreads' => 'tns:ArrayOfForumThread'),
	$uri, 
	$uri.'#getForumThreads',
	'rpc',
	'encoded'
);


/**
 * SOAP method to retrieve a list of ForumThread
 * @param	$forum_thread_id	Filter by forum_thread_id
 * @param	$forum_id	Filter by forum_id
 * @param	$created_by	Filter by created_by
 * @param	$thread_name	Filter by thread_name
 * @param	$message_count	Filter by message_count
 * @param	$most_recent_date	Filter by most_recent_date
 */
function getForumThreads($sessionHash, $forum_id, $created_by, $thread_name, $msg_count_min, $msg_count_max, $recent_date_min, $recent_date_max) {
	$ip = $_SERVER['REMOTE_ADDR'];
	Session::getSession()->setup($sessionHash, $ip);

	$crit = new Criteria();
	
	if (!is_null($forum_id) && $forum_id > 0) {
		$crit->add(ForumThreadPeer::FORUM_ID, $forum_id);
	}
	if (!is_null($created_by) && $created_by > 0) {
		$crit->add(ForumThreadPeer::CREATED_BY, $created_by);
	}
	if (!is_null($thread_name) && $thread_name != '') {
		$crit->add(ForumThreadPeer::THREAD_NAME, $thread_name);
	}
	if(!is_null($msg_count_min) && $msg_count_min > -1) {
		$crit->add(ForumThreadPeer::MESSAGE_COUNT, $msg_count_min, Criteria::GREATER_EQUAL);
	}
	if(!is_null($msg_count_max) && $msg_count_max > -1) {
		$crit->add(ForumThreadPeer::MESSAGE_COUNT, $msg_count_max, Criteria::LESS_EQUAL);
	}
	if(!is_null($recent_date_min) && $recent_date_min != '') {
		$crit->add(ForumThreadPeer::MOST_RECENT_DATE, $recent_date_min, Criteria::GREATER_EQUAL);
	}
	if(!is_null($recent_date_max) && $recent_date_max != '') {
		$crit->add(ForumThreadPeer::MOST_RECENT_DATE, $recent_date_max, Criteria::LESS_EQUAL);
	}
	$objs = ForumThreadPeer::doSelect($crit);
	$res = array();
	foreach ($objs as $obj) {
		if ($obj->getForum()->userCanRead()) {
			$res[] = ForumThreadToSOAP($obj);
		}
	}
	return $res;
}

$server->register(
	'getForumThreadArray',
	array(
		'sessionHash'	=> 'xsd:string',
		'forum_thread_id' => 'ArrayOfxsd:int',
	), 
	array('getForumThread' => 'tns:ArrayOfForumThread'),
	$uri, 
	$uri.'#getForumThread',
	'rpc',
	'encoded'
);

/**
 * SOAP method to retrieve an array of ForumThread
 * @param	$forum_thread_id	Retrieve the ForumThread array identified by the array of forum_thread_id
 */
function getForumThreadArray($sessionHash, $forum_thread_idArr) {
	$ip = $_SERVER['REMOTE_ADDR'];
	Session::getSession()->setup($sessionHash, $ip);

	$ret = array();

	$crit=new Criteria();
        $crit->add(ForumThreadPeer::FORUM_THREAD_ID,$forum_thread_idArr,Criteria::IN);
	$objs = ForumThreadPeer::doSelect($crit);
	foreach ($objs as $obj) {
		if ($obj->getForum()->userCanRead()) {
			$ret[] = ForumThreadToSOAP($obj);
		}
	}
	return $ret;
}

$server->register(
	'getForumThread',
	array(
		'sessionHash'	=> 'xsd:string',
		'forum_thread_id' => 'xsd:int',
	), 
	array('getForumThread' => 'tns:ForumThread'),
	$uri, 
	$uri.'#getForumThread',
	'rpc',
	'encoded'
);

/**
 * SOAP method to retrieve a single ForumThread
 * @param	$forum_thread_id	Retrieve the ForumThread identified by this forum_thread_id
 */
function getForumThread($sessionHash, $forum_thread_id) {
	$ip = $_SERVER['REMOTE_ADDR'];
	Session::getSession()->setup($sessionHash, $ip);

	$obj = ForumThreadPeer::retrieveByPK($forum_thread_id);
	if (is_null($obj)) {
		return null;
	}
	if (!$obj->getForum()->userCanRead()) {
		return new soap_fault('', 'getForumThread','Permission Denied - Cannot View This Record','Permission Denied - Cannot View This Record');
	}
	return ForumThreadToSOAP($obj);
}

$server->register(
	'updateForumThread',
	array(
		'sessionHash'	=> 'xsd:string',
		'forum_thread_id' => 'xsd:int',
		'thread_name' => 'xsd:string',
	), 
	array('updateForumThread' => 'xsd:int'),
	$uri, 
	$uri.'#updateForumThread',
	'rpc',
	'encoded'
);

/**
 * SOAP method to update ForumThread
 * @param	$forum_thread_id	 ForumThread to update
 * @param	$forum_id
 * @param	$created_by
 * @param	$thread_name
 * @param	$message_count
 * @param	$most_recent_date
 */
function updateForumThread($sessionHash, $forum_thread_id, $thread_name) {
	$ip = $_SERVER['REMOTE_ADDR'];
	Session::getSession()->setup($sessionHash, $ip);

	$obj = ForumThreadPeer::retrieveByPK($forum_thread_id);
	if (is_null($obj) || !$obj->getForum()->userCanPost(Session::getSession()->getUser())) {
		throw new soap_fault('', 'updateForumThread', 'Couldn\'t update ForumThread: invalid forum_thread_id '.$forum_thread_id);
	}
	
	if (!is_null($thread_name)) {
		$obj->setThreadName( Validator::sanitizeString($thread_name) );
	}
	
	try {
		$obj->save();
	} catch (Exception $e) {
		return new soap_fault('', 'updateForumThread','Permission Denied - Cannot update This Record',$e->getMessage());
	}
	return 1;
}



$server->register(
	'addForumThread',
	array(
		'sessionHash'	=> 'xsd:string',
		'forum_id' => 'xsd:int',
		'thread_name' => 'xsd:string',
	), 
	array('addForumThread' => 'xsd:int'),
	$uri, 
	$uri.'#addForumThread',
	'rpc',
	'encoded'
);


/**
 * SOAP method to add a ForumThread
 * @param	$forum_id
 * @param	$created_by
 * @param	$thread_name
 * @param	$message_count
 * @param	$most_recent_date
 */
function addForumThread($sessionHash, $forum_id, $thread_name) {
	$ip = $_SERVER['REMOTE_ADDR'];
	Session::getSession()->setup($sessionHash, $ip);

	$forum_id = Validator::sanitizeInt($forum_id);
	$forum = ForumPeer::retrieveByPk($forum_id);
	if(!is_object($forum)) {
		return new soap_fault('', 'addForumThread','Permission Denied - Invalid Forum');	
	}
	
	if(!$forum->userCanPost(Session::getSession()->getUser())) {
		return new soap_fault('', 'addForumThread','Permission Denied - You dont have posting permissions in this Forum');
	}
	
	$obj = new ForumThread();
	
	$obj->setForumId( Validator::sanitizeInt($forum_id) );
	$obj->setCreatedBy( Session::getSession()->getUser()->getUserId() );
	$obj->setThreadName( Validator::sanitizeString($thread_name) );
	$obj->setMessageCount( 0 );
	try {
		$obj->save();
		return $obj->getForumThreadId();
	} catch (Exception $e) {
		return new soap_fault('', 'addForumThread','Permission Denied - Cannot add This Record',$e->getMessage());
	}
}


$server->register(
	'deleteForumThread',
	array(
		'sessionHash'	=> 'xsd:string',
		'forum_thread_id' => 'xsd:int',
	), 
	array('deleteForumThread' => 'xsd:int'),
	$uri, 
	$uri.'#deleteForumThread',
	'rpc',
	'encoded'
);

/**
 * SOAP method to delete a single ForumThread
 * @param	$forum_thread_id
 */
function deleteForumThread($sessionHash, $forum_thread_id) {
	$ip = $_SERVER['REMOTE_ADDR'];
	Session::getSession()->setup($sessionHash, $ip);

	$obj = ForumThreadPeer::retrieveByPK($forum_thread_id);
	if (is_null($obj) || !$obj->getForum()->userCanDelete()) {
		return new soap_fault('', 'deleteForumThread','Permission Denied - Cannot Delete This Record','Permission Denied - Cannot View This Record');
	}
	try {
		$obj->delete();
	} catch (Exception $e) {
		return new soap_fault('', 'deleteForumThread','Permission Denied - Cannot Delete This Record',$e->getMessage());
	}
	return 1;
}

function ForumThreadToSOAP(&$obj) {
	$ret = array();
	$ret['forum_thread_id'] = $obj->getForumThreadId();
	$ret['forum_id'] = $obj->getForumId();
	$ret['created_by'] = $obj->getCreatedBy();
	$ret['thread_name'] = $obj->getThreadName();
	$ret['message_count'] = $obj->getMessageCount();
	$ret['most_recent_date'] = $obj->getMostRecentDate();
	return $ret;
}
?>