<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id: Layout.php 270 2005-12-31 03:02:47Z tperdue $
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

// This code generates a SOAP API for handling TrackerItemMessage

require_once('plugins/tracker/lib/TrackerItemMessage.php');
require_once('plugins/tracker/lib/TrackerItemMessagePeer.php');
require_once('plugins/tracker/lib/TrackerItem.php');
require_once('plugins/tracker/lib/TrackerItemPeer.php');
require_once('Validator.php');

/* ******************************************************************** */
/*                                 DATA TYPES                           */
/* ******************************************************************** */
$server->wsdl->addComplexType(
	'TrackerItemMessage',
	'complexType',
	'struct',
	'sequence',
	'',
	array(
		'tracker_item_message_id' => array('name'=>'tracker_item_message_id', 'type' => 'xsd:int'),
		'tracker_item_id' => array('name'=>'tracker_item_id', 'type' => 'xsd:int'),
		'submitted_by' => array('name'=>'submitted_by', 'type' => 'xsd:int'),
		'adddate' => array('name'=>'adddate', 'type' => 'xsd:string'),
		'body' => array('name'=>'body', 'type' => 'xsd:string'),
	)
);


$server->wsdl->addComplexType(
	'ArrayOfTrackerItemMessage',
	'complexType',
	'array',
	'',
	'SOAP-ENC:Array',
	array(),
	array(array('ref' => 'SOAP-ENC:arrayType', 'wsdl:arrayType' => 'tns:TrackerItemMessage[]')),
	'tns:TrackerItemMessage'
);

/* ******************************************************************** */
/*                                 METHODS                              */
/* ******************************************************************** */

$server->register(
	'getTrackerItemMessages',
	array(
		'sessionHash'	=> 'xsd:string',
		'tracker_item_id' => 'xsd:int',
		'submitted_by' => 'xsd:int'
	), 
	array('getTrackerItemMessages' => 'tns:ArrayOfTrackerItemMessage'),
	$uri, 
	$uri.'#getTrackerItemMessages',
	'rpc',
	'encoded'
);


/**
 * SOAP method to retrieve a list of TrackerItemMessage
 * @param	$tracker_item_id	Filter by tracker_item_id
 * @param	$submitted_by	Filter by submitted_by
 */
function getTrackerItemMessages($sessionHash, $tracker_item_id, $submitted_by) {
	$ip = $_SERVER['REMOTE_ADDR'];
	Session::getSession()->setup($sessionHash, $ip);

	if (!checkTrackerItemPermission($tracker_item_id)) {
		return new soap_fault('', 'getTrackerItemMessages','Permission Denied - Cannot View This Record','Permission Denied - Cannot View This Record');
	}

	$c = new Criteria();
	$c->add(TrackerItemMessagePeer::TRACKER_ITEM_ID, $tracker_item_id);

	if ($submitted_by >=0) {
		$c->add(TrackerItemMessagePeer::SUBMITTED_BY, $submitted_by);
	}
	
	$objs = TrackerItemMessagePeer::doSelect($c);
	$res = array();
	foreach ($objs as $obj) {
		$res[] = TrackerItemMessageToSOAP($obj);
	}
	
	return $res;
}

$server->register(
	'getTrackerItemMessageArray',
	array(
		'sessionHash'	=> 'xsd:string',
		'tracker_item_id' => 'tns:ArrayOfInt',
		'tracker_item_message_id' => 'tns:ArrayOfInt',
	), 
	array('getTrackerItemMessage' => 'tns:ArrayOfTrackerItemMessage'),
	$uri, 
	$uri.'#getTrackerItemMessage',
	'rpc',
	'encoded'
);

/**
 * SOAP method to retrieve an array of TrackerItemMessage
 * @param	$tracker_item_id	Retrieve from this tracker item
 * @param	$tracker_item_message_id	Retrieve the TrackerItemMessage array identified by the array of tracker_item_message_id
 */
function getTrackerItemMessageArray($sessionHash, $tracker_item_id, $tracker_item_message_idArr) {
	$ip = $_SERVER['REMOTE_ADDR'];
	Session::getSession()->setup($sessionHash, $ip);

	if (!checkTrackerItemPermission($tracker_item_id)) {
		return new soap_fault('', 'getTrackerItemMessageArray','Permission Denied - Cannot View This Record','Permission Denied - Cannot View This Record');
	}

	$ret = array();

	$crit=new Criteria();
	$crit->add(TrackerItemMessagePeer::TRACKER_ITEM_MESSAGE_ID,$tracker_item_message_idArr,Criteria::IN);
	$crit->add(TrackerItemMessagePeer::TRACKER_ITEM_ID, $tracker_item_id);
	$objs = TrackerItemMessagePeer::doSelect($crit);
	foreach ($objs as $obj) {
		$ret[] = TrackerItemMessageToSOAP($obj);
	}
	return $ret;
}

$server->register(
	'getTrackerItemMessage',
	array(
		'sessionHash'	=> 'xsd:string',
		'tracker_item_id' => 'xsd:int',
		'tracker_item_message_id' => 'xsd:int',
	), 
	array('getTrackerItemMessage' => 'tns:TrackerItemMessage'),
	$uri, 
	$uri.'#getTrackerItemMessage',
	'rpc',
	'encoded'
);

/**
 * SOAP method to retrieve a single TrackerItemMessage
 * @param	$tracker_item_id	Retrieve from this tracker item
 * @param	$tracker_item_message_id	Retrieve the TrackerItemMessage identified by this tracker_item_message_id
 */
function getTrackerItemMessage($sessionHash, $tracker_item_id, $tracker_item_message_id) {
	$ip = $_SERVER['REMOTE_ADDR'];
	Session::getSession()->setup($sessionHash, $ip);

	if (!checkTrackerItemPermission($tracker_item_id)) {
		return new soap_fault('', 'getTrackerItemMessage','Permission Denied - Cannot View This Record','Permission Denied - Cannot View This Record');
	}

	$obj = TrackerItemMessagePeer::retrieveByPK($tracker_item_message_id);
	if (is_null($obj) || $obj->getTrackerItemId() != $tracker_item_id) {
		return null;
	}
	return TrackerItemMessageToSOAP($obj);
}

$server->register(
	'deleteTrackerItemMessage',
	array(
		'sessionHash'	=> 'xsd:string',
		'tracker_item_id' => 'xsd:int',
		'tracker_item_message_id' => 'xsd:int',
	), 
	array('deleteTrackerItemMessage' => 'xsd:int'),
	$uri, 
	$uri.'#deleteTrackerItemMessage',
	'rpc',
	'encoded'
);

/**
 * SOAP method to delete a single TrackerItemMessage
 * @param	$tracker_item_id	Delete from this tracker item
 * @param	$tracker_item_message_id	Delete the TrackerItemMessage identified by this tracker_item_message_id
 */
function deleteTrackerItemMessage($sessionHash, $tracker_item_id, $tracker_item_message_id) {
	$ip = $_SERVER['REMOTE_ADDR'];
	Session::getSession()->setup($sessionHash, $ip);

	if (!checkTrackerItemPermission($tracker_item_id, 'delete')) {
		return new soap_fault('', 'deleteTrackerItemMessage','Permission Denied - Cannot Delete This Record','Permission Denied - Cannot View This Record');
	}

	$obj = TrackerItemMessagePeer::retrieveByPK($tracker_item_message_id);
	if (is_null($obj) || $obj->getTrackerItemId() != $tracker_item_id) {
		return new soap_fault('', 'deleteTrackerItemMessage','Permission Denied - Cannot Delete This Record','Permission Denied - Cannot View This Record');
	}
	try {
		$obj->delete();
		return 1;
	} catch (Exception $e) {
		return new soap_fault('', 'deleteTrackerItemMessage','Permission Denied - Cannot Delete This Record',$e->getMessage());
	}
}

/*
$server->register(
	'updateTrackerItemMessage',
	array(
		'sessionHash'	=> 'xsd:string',
		'tracker_item_id' => 'xsd:int',
		'tracker_item_message_id' => 'xsd:int',
		'submitted_by' => 'xsd:int',
		'adddate' => 'xsd:string',
		'body' => 'xsd:string',
	), 
	array('updateTrackerItemMessage' => 'xsd:int'),
	$uri, 
	$uri.'#updateTrackerItemMessage',
	'rpc',
	'encoded'
);
*/

/**
 * SOAP method to update TrackerItemMessage
 * @param	$tracker_item_id
 * @param	$tracker_item_message_id	 TrackerItemMessage to update
 * @param	$submitted_by
 * @param	$adddate
 * @param	$body
 */
 
/*
function updateTrackerItemMessage($sessionHash, $tracker_item_id, $tracker_item_message_id, $body) {
	$ip = $_SERVER['REMOTE_ADDR'];
	Session::getSession()->setup($sessionHash, $ip);

	if (!checkTrackerItemPermission($tracker_item_id, 'update') {
		return new soap_fault('', 'updateTrackerItemMessage','Permission Denied - Cannot View This Record','Permission Denied - Cannot View This Record');
	}

	$obj = TrackerItemMessagePeer::retrieveByPK($tracker_item_message_id);
	if (is_null($obj)) {
		return new soap_fault('', 'updateTrackerItemMessage', 'Couldn\'t update TrackerItemMessage: invalid tracker_item_message_id '.$tracker_item_message_id);
	}
	if ($obj->getSubmittedBy() != Session::getSession()->getUser()->getUserId()) {
		return new soap_fault('', 'updateTrackerItemMessage','Permission Denied - Cannot update This Record','Permission Denied - Cannot update This Record');
	}
	
	if (!is_null($body)) {
		$obj->setBody( Validator::sanitizeString($body) );
	}
	
	try {
		$obj->save();
	} catch (Exception $e) {
		return new soap_fault('', 'updateTrackerItemMessage','Permission Denied - Cannot update This Record',$e->getMessage());
	}
	return 1;
}
*/

$server->register(
	'addTrackerItemMessage',
	array(
		'sessionHash'	=> 'xsd:string',
		'tracker_item_id' => 'xsd:int',
		'body' => 'xsd:string',
	), 
	array('addTrackerItemMessage' => 'xsd:int'),
	$uri, 
	$uri.'#addTrackerItemMessage',
	'rpc',
	'encoded'
);


/**
 * SOAP method to add a TrackerItemMessage
 * @param	$tracker_item_id
 * @param	$submitted_by
 * @param	$adddate
 * @param	$body
 */
function addTrackerItemMessage($sessionHash, $tracker_item_id, $body) {
	$ip = $_SERVER['REMOTE_ADDR'];
	Session::getSession()->setup($sessionHash, $ip);

	if (!checkTrackerItemPermission($tracker_item_id, 'update')) {
		return new soap_fault('', 'addTrackerItemMessage','Permission Denied - Cannot add This Record','Permission Denied - Cannot View This Record');
	}

	$TrackerItem = TrackerItemPeer::retrieveByPk($tracker_item_id);
	if(!is_object($TrackerItem)) {
		return new soap_fault('', 'addTrackerItemMessage','Invalid Tracker Item ID','Invalid Tracker Item ID');
	}
	
	$obj = new TrackerItemMessage();
	$obj->setTrackerItemId( Validator::sanitizeInt($tracker_item_id) );
	$obj->setSubmittedBy( Session::getSession()->getUser()->getUserId() );
	$obj->setBody( Validator::sanitizeString($body) );
	try {
		$obj->save();
		//Save the tracker item so notifications get sent
		$TrackerItem->save();
		return $obj->getTrackerItemMessageId();
	} catch (Exception $e) {
		return new soap_fault('', 'addTrackerItemMessage','Permission Denied - Cannot add This Record',$e->getMessage());
	}
}

function TrackerItemMessageToSOAP(&$obj) {
	$ret = array();
	$ret['tracker_item_message_id'] = $obj->getTrackerItemMessageId();
	$ret['tracker_item_id'] = $obj->getTrackerItemId();
	$ret['submitted_by'] = $obj->getSubmittedBy();
	$ret['adddate'] = $obj->getAdddate();
	$ret['body'] = $obj->getBody();
	return $ret;
}
?>
