<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id: User.php 326 2006-01-09 19:49:12Z danper $
 * @author Daniel A. Perez	daniel@gforgegroup.com
 * @date 2005-11-11
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */

require_once('lib/core/UserPeer.php');
require_once('lib/core/User.php');
require_once('html/SiteTemplate.php');
require_once('lib/StringUtils.php');
require_once 'session/LoginFactory.php';

if (Session::getSession()->isLoggedIn()) {
	// if user is already logged in, go to the logout page
	header('Location: /gf/account/?action=Logout');
}

if (isset($_REQUEST['confirm_hash'])) {
	$confirm_hash = $_REQUEST['confirm_hash'];
} else {
	$confirm_hash = null;
}

$feedback = '';

if (isset($_REQUEST['submit'])) {
	if (isset($_REQUEST['loginname'])) {
		$loginname = $_REQUEST['loginname'];
	} else {
		$loginname = null;
	}	
	if (isset($_REQUEST['passwd'])) {
		$passwd = $_REQUEST['passwd'];
	} else {
		$passwd = null;
	}	

	if ((!$loginname) || (!$passwd)) {
		$feedback .= Language::getSessText('Verify.Missing') . '<br />';
	} else {
		$user = UserPeer::retrieveByUnixName($loginname);
		if (!is_object($user)) {
			$feedback .= Language::getSessText('Verify.NotGetUser') . '<br />';
		} else {
			if ($user->getStatus()==User::STATUS_ACTIVE) {
				$feedback .= Language::getSessText('Verify.AlreadyActive') . '<br />';
			} else {
				$confirm_hash = StringUtils::prepareHash($confirm_hash);
				if ($confirm_hash != $user->getConfirmHash()) {
					$feedback .= Language::getSessText('LostLogin.InvalidHash') . '<br />';
				} else {
					try {
						$login = LoginFactory::getLogin();
						Session::getSession()->terminate();
						$userSession = $login->doLogin($loginname, $passwd, false);
						$session = Session::getSession();
						$session->setUserSession($userSession, $_SERVER["REMOTE_ADDR"]);
						$sessionHash = $session->getSessionHash();
						$sessionTimeout = GFConf::get("system.sessionTimeout");
						setcookie("sessionHash", $sessionHash, time()+$sessionTimeout, "/");
						$user->setStatus(User::STATUS_ACTIVE);
						$user->save();
						$mon = $user->setSiteMonitoring(true);
						$feedback .= Language::getSessText('Verify.Verified') . '<br />';
						GFUrl::getUrl()->redirect(GFUrl::getUrl()->baseURL()); // TODO -> redirect to some "first time user" page
					} catch (Exception $e) {
						$error = $e->getMessage();
						$feedback .= $error . '<br />';
					}					
				}
			}
		}
	}
}

$template = new SiteTemplate();
$params = array(
		'selectedtoptab' => 'my', 
		'feedback' => $feedback,
		'title'=>Language::getSessText('Common.Login')
	);
$template->header($params);

echo Language::getSessText('Verify.Blurb');

?>

<form action="<?php echo GFUrl::getUrl()->currentBaseURL('verify'); ?>" method="post">

<p><?php echo Language::getSessText('Verify.LoginName'); ?>
<br /><input type="text" name="loginname" /></p>
<p><?php echo Language::getSessText('User.Password'); ?> :
<br /><input type="password" name="passwd" /></p>
<input type="hidden" name="confirm_hash" value="<?php echo $confirm_hash; ?>" />
<p><?php echo HTMLWidget::button("submit","" .   Language::getSessText('Common.Login') . " ","submit","","")?></p>
</form>

<?php
$template->footer();

?>
