<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version   $Id$
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */
//
// This code edits a Role and saves it to the 
// database
//
require_once('core/Role.php');
require_once('Validator.php');
require_once('exceptions/PermissionDeniedException.php');
require_once('core/Language.php');
require_once('exceptions/MissingDataException.php');

$project = GFUrl::getUrl()->getProject();
if (!$project->userIsAdmin()) {
	// Only project admins can change member information
	throw new PermissionDeniedException();
}

if ($_SERVER['REQUEST_METHOD'] != 'POST') {
	throw new PermissionDeniedException();
}

if (!array_key_exists('data', $_POST)) {
	throw new MissingDataException('Missing role data');
}

$Lang = Language::getSessLang();

try {
	$role = new Role();
	$role->setProjectId($project->getProjectId());
	$role->setRoleName( Validator::sanitizeString($_POST['role_name']) );
	$role->save();

	$data = $_POST['data'];
	
	// Save project admin data
	if (isset($data['projectadmin'])) {
		$value = $data['projectadmin'][0];
		$c = new Criteria();
		$c->add(RoleSettingPeer::ROLE_ID, $role->getPrimaryKey());
		$c->add(RoleSettingPeer::SECTION, 'projectadmin');
		$c->add(RoleSettingPeer::REF_ID, 0);
		$rolesetting = RoleSettingPeer::doSelectOne($c);
		if (!is_object($rolesetting)) {
			// Enter here if we have a role setting which we didn't have previously (e.g.: activate an inactive plugin)
			$rolesetting = new RoleSetting();
			$rolesetting->setSection('projectadmin');
			$rolesetting->setRefId(0);
			$rolesetting->setRoleId($role->getPrimaryKey());
		}
		$rolesetting->setValue($value);
		$rolesetting->save();						
	}
	
	// Now inform the plugins
	$params = array('project' => $project, 'data' => $data, 'role' => $role);
	ActionManager::notify('UPDATE_ROLE_CHOICES', $params);
	
	$url = GFUrl::getUrl();
	GFUrl::redirect($url->currentBaseURL('RoleBrowse'), array('feedback' => $Lang->getText('ProjectAdmin.Role.Created')));
} catch (InvalidDataException $ex) {
	$errors = $ex->getErrors();
	$feedback = implode('<br />', $errors);
	include('RoleAdd.php');
}

?>
