<?php
/**
 * Copyright (c) 2005-2008 GForge, LLC
 *
 * @version $Id$
 *
 * This file is part of GForge.
 *
 * See LICENSE for details. This file is part of GForge AS and may not be
 * redistributed without written permission of GForge, LLC
 */
require_once('lib/RssGenerator.php');
require_once('core/UserPeer.php');
require_once('session/LoginFactory.php');

$session = Session::getSession();
$Lang = $session->getLanguage();
$url = GFUrl::getUrl();

$section = (isset($_GET['section'])) ? $_GET['section'] : '';
$ref_id  = (isset($_GET['ref_id'])) ? intval($_GET['ref_id']) : 0;
$project_id  = (isset($_GET['project_id'])) ? intval($_GET['project_id']) : 0;



function processLogin($username, $password) {
	$login = LoginFactory::getLogin();
	try {
		$userSession = $login->doLogin($username, $password);
	}
	catch (Exception $e){
		return("");
	}
	return($userSession);
}


function validateLogin($session) {
	$ip = $_SERVER["REMOTE_ADDR"];
	
	$user = $session->getUser();
	if (!is_object($user)) {
		if (!isset($_SERVER['PHP_AUTH_USER']) && !isset($_SERVER['PHP_AUTH_PW'])) {
			header('WWW-Authenticate: Basic realm="Restricted access"');
			header('HTTP/1.0 401 Unauthorized');
			echo 'Authentication requested';
			exit;
		} else {
			$username = $_SERVER['PHP_AUTH_USER'];
			$password = $_SERVER['PHP_AUTH_PW'];
			$userSession = processLogin($username, $password);
			if (is_object($userSession)) {
				$session->setUserSession($userSession, $ip);
				return($session);
			} else {
				header('WWW-Authenticate: Basic realm="Restricted access"');
				header('HTTP/1.0 401 Unauthorized');
				echo 'Authentication requested';
				exit;				
			}
		}
	} else {
		return($session);
	}	
}

if (!empty($section) || $ref_id != 0) {
	switch ($section) {

	/*
		RSS Feeds for activity in a specific project
	*/
	case 'activity':	
		$project = ProjectPeer::retrieveByPk($project_id);
		if (!$project->isPublic()) {
			$session = validateLogin($session);
		}
		$user = $session->getUser();
		
		if (!is_object($project)  || !$project->userCanRead()) {
			exit();
		}

		// Get the latest activity items
		$con = Propel::getConnection(UserPeer::DATABASE_NAME);
		$stmt = $con->createStatement();
		$sql="SELECT * FROM project_activity_vw
			WHERE project_id=".$project->getProjectId()."
			ORDER BY activity_date DESC LIMIT 15 OFFSET 0";
		$rs = $stmt->executeQuery($sql);

		$rss = new RssGenerator();
		$channelName = GFConf::get('system.name').' - '.$project->getName().' - Activity';
		$rss->addChannel($channelName, $url->getFullURL($url->baseURL()), 'Gforge Advanced Server RSS');

		while ($rs->next()) {
			$arr = $rs->getRow();
			$author = UserPeer::retrieveByPk($arr['user_id'])->getName().' &lt;'.UserPeer::retrieveByPk($arr['user_id'])->getEmail().'&gt;';

			switch ($arr['section']) {
				case 'scm':
					$activity_desc = $Lang->getText('ProjectActivity.CommitDescription', array($arr['description1']));
					$scmplugin = $project->getExclusiveTypePlugin('scm');
					if (is_null($scmplugin)) continue;  // shouldn't happen... means SCM was disabled in the project
					$link = $url->getFullURL($url->projectURL($project, 'ScmCommitDetail', $scmplugin->getName(), '', array('scm_commit_id'=>$arr['ref_id'])));
					break;
				case 'trackeritem':
					$action = $arr['action'];
					switch ($action) {
					case 'create':
						$activity_desc = $Lang->getText('ProjectActivity.TrackerItemCreate', array($arr['description1']));
						$link = GFUrl::getURL()->projectURL($project, 'TrackerItemEdit', 'tracker', '', array('tracker_item_id'=>$arr['ref_id'],'tracker_id'=>$arr['ref_id']));
						break;
					case 'delete':
						// We can't link to the item since it was deleted. Link to the tracker instead
						$activity_desc = $Lang->getText('ProjectActivity.TrackerItemDelete', array($arr['description1']));
						$link = GFUrl::getURL()->projectURL($project, '', 'tracker');
						break;
					case 'statuschange':
						$activity_desc = $Lang->getText('ProjectActivity.TrackerItemStatusChange', array($arr['description1'], $arr['description2']));
						$link = GFUrl::getURL()->projectURL($project, 'TrackerItemEdit', 'tracker', '', array('tracker_item_id' => $arr['ref_id'],'tracker_id'=>$arr['ref_id']));
						break;
					default:
						continue;
					}
					break;
				case 'forum':
					$activity_desc = $Lang->getText('ProjectActivity.ForumPostDescription', array($arr['description1']));
					$link = $url->getFullURL($url->projectURL($project, 'ForumBrowse', 'forum', '', array('_forum_action'=>'MessageReply','message_id'=>$arr['subref_id'])));
					break;
			}

			$rss->addItem($channelName,
				      array('title' => $activity_desc,
					    'link' => '<![CDATA['.$link.']]>',
					    'author' => $author,
					    'guid' => '<![CDATA['.$link.']]>',
					    'description' => $arr['description1']));
		}
		echo $rss->getRss();

		break;

	case 'myforums':
		$session = validateLogin($session);
		$User = $session->getUser();
	
		$latest_messages_data = ForumPeer::getLatestMonitoredThreads($User, 'project');

		$rss = new RssGenerator();
		$channelName = GFConf::get('system.name').' - Monitored Forums';
		$rss->addChannel($channelName, $url->getFullURL($url->baseURL()), 'Gforge Advanced Server RSS');
		foreach ($latest_messages_data as $data) {
			$project = $data['project'];

			foreach ($data['threads'] as $latest_threads_data) {
				$forum = $latest_threads_data['forum'];
				if (!is_object($forum)) {
					continue;
				}
				$latest_threads = $latest_threads_data['latest_threads'];
				foreach ($latest_threads as $thread_data) {
					$thread = $thread_data['thread'];
					$message = $thread_data['latest_message'];
					$user = $thread_data['user'];
					$author = $user->getName().' &lt;'.$user->getEmail().'&gt;';
					$link = $url->getFullURL($url->projectUrl($project, 'ForumBrowse', '', 'forum', array('_forum_action' => 'ForumMessageBrowse', 'thread_id' => $thread->getForumThreadId())));
					$rss->addItem($channelName,
						      array('title' => $forum->getForumName().' &gt; '.$thread->getThreadName(),
							    'link' => '<![CDATA['.$link.']]>',
							    'author' => $author,
							    'guid' => '<![CDATA['.$link.']]>',
							    'description' => $message->getBody()));
				}
			}
		}
		echo $rss->getRss();
		break;

		case 'projectnews':
		$project = ProjectPeer::retrieveByPk($project_id);
		if (!$project->isPublic()) {
			$session = validateLogin($session);
		}
		$User = $session->getUser();

		if ((!is_object($project)) || (!$project->userCanRead())) {
			exit();
		}

		// Get the latest news
		$con = Propel::getConnection(UserPeer::DATABASE_NAME);
		$stmt = $con->createStatement();
		$sql="SELECT * FROM news
			WHERE project_id=".$project_id."
			ORDER BY post_date DESC LIMIT 15 OFFSET 0";
		$rs = $stmt->executeQuery($sql);
		
		$rss = new RssGenerator();
		$channelName = GFConf::get('system.name').' - Project News';
		$rss->addChannel($channelName, $url->getFullURL($url->baseURL()), 'Gforge Advanced Server RSS');

		while ($rs->next()) {
			$arr = $rs->getRow();
		
			$user_posted = UserPeer::retrieveByPk($arr['submitted_by']);
			if (is_object($user_posted)) {
				$author = $user_posted->getName();
			} else {
				$author = "";
			}		
			$link = $url->getFullURL($url->projectUrl($project, 'NewsThreadView', '', 'news', array('id' => $arr['news_id'])));
			$rss->addItem($channelName,
						      array('title' => $arr['summary'],
							    'link' => '<![CDATA['.$link.']]>',
							    'author' => $author,
							    'guid' => '<![CDATA['.$link.']]>',
							    'description' => $arr['details']));
		}
		echo $rss->getRss();
		break;

		case 'sitenews':
		$session = validateLogin($session);
		$user = $session->getUser();

		// Get the latest site news
		$con = Propel::getConnection(UserPeer::DATABASE_NAME);
		$stmt = $con->createStatement();
		$sql="SELECT * FROM news
			WHERE is_approved = true
			ORDER BY post_date DESC LIMIT 15 OFFSET 0";
		$rs = $stmt->executeQuery($sql);
		
		$rss = new RssGenerator();
		$channelName = GFConf::get('system.name').' - Site News';
		$rss->addChannel($channelName, $url->getFullURL($url->baseURL()), 'Gforge Advanced Server RSS');

		while ($rs->next()) {
			$arr = $rs->getRow();

			$project = ProjectPeer::retrieveByPk($arr['project_id']);
			if (is_object($project) && ($project->isPublic() || $project->userCanRead())) {
				$user_posted = UserPeer::retrieveByPk($arr['submitted_by']);
				if (is_object($user_posted)) {
					$author = $user_posted->getName();
				} else {
					$author = "";
				}		
				$link = $url->getFullURL($url->projectUrl($project, 'NewsThreadView', '', 'news', array('id' => $arr['news_id'])));
				$rss->addItem($channelName,
								      array('title' => $arr['summary'],
									    'link' => '<![CDATA['.$link.']]>',
									    'author' => $author,
									    'guid' => '<![CDATA['.$link.']]>',
									    'description' => $arr['details']));
			}
		}
		echo $rss->getRss();
		break;

	case 'siteposts':
		$con = Propel::getConnection(UserPeer::DATABASE_NAME);
		$stmt = $con->createStatement();
		$sql="SELECT forum_message.subject, forum_message.body, forum_thread.thread_name, forum.section, 
			forum.ref_id, forum.forum_id, forum_message.forum_message_id, forum_thread.forum_thread_id,
			forum_message.created_by
			FROM forum_message, forum_thread, forum
			WHERE
			forum_message.forum_thread_id = forum_thread.forum_thread_id AND
			forum_thread.forum_id = forum.forum_id
			AND forum.is_public = true AND forum.section = 'project'
			ORDER BY forum_message.post_date DESC LIMIT 15 OFFSET 0";
		$rs = $stmt->executeQuery($sql);
		//print_r ($rs);exit;
		$rss = new RssGenerator();
		$channelName = GFConf::get('system.name').' - Project News';
		$rss->addChannel($channelName, $url->getFullURL($url->baseURL()), 'Gforge Advanced Server RSS');

		while ($rs->next()) {
			$arr = $rs->getRow();
			$user_posted = UserPeer::retrieveByPk($arr['created_by']);
			if (is_object($user_posted)) {
				$author = $user_posted->getName();
			} else {
				$author = "";
			}
			$project = ProjectPeer::retrieveByPk($arr['ref_id']);
			if (!is_object($project) || !$project->isPublic()) {
				continue;
			} else {
				$project_unixname = $project->getUnixName();
				$project_name = $project->getProjectName();
			}
			$link = $url->getFullURL($url->projectUrl($project, 'ForumBrowse', '', 'forum', array('_forum_action' => 'MessageReply','message_id' => $arr['forum_message_id'], 'thread_id' => $arr['forum_thread_id'], 'forum_id' => $arr['forum_id'])));
			$rss->addItem($channelName,
							      array('title' => $project_name.": ".$arr['subject'],
								    'link' => '<![CDATA['.$link.']]>',
								    'author' => $author,
								    'guid' => '<![CDATA['.$link.']]>',
								    'description' => $arr['body']));
		}
		echo $rss->getRss();
		break;

	default:
		$project = ProjectPeer::retrieveByPk($project_id);
 		
 		if (!is_object($project)) {
			exit();
		}
 		
 		if (!$project->userCanRead()) {
			$session = validateLogin($session);
			$user = $session->getUser();
		}
		
		// UGLY HACK: we need to reset the permissions in $project since we called
		// $project->getPermissions() before logging in, and $project->permissions is stored on
		// a cache.
		$project->purgePermissions();

		$rss = new RssGenerator();

		$data = array('project' => $project,
			      'section' => $section,
			      'ref_id' => $ref_id);

		$plugin_results = ActionManager::notify("BUILD_RSS_FEED", $data);
		foreach ($plugin_results as $result) {
			$resarr = $result->getResult();
			if (!$resarr) {
			    continue;
			}
			foreach ($resarr as $key => $value) {
				if ($key == 'channel') {
					$rss->addChannel($value['name'], $value['url'], $value['description']);
				}
				if ($key == 'items') {
					foreach ($value as $item) {
						$rss->addItem($item['channel_name'],
							      array('title' => $item['title'],
								    'link' => $item['link'],
								    'author' => $item['author'],
								    'guid' => $item['guid'],
								    'description' => $item['description']));
					}
				}
			}
		}
		echo $rss->getRss();
	}
	exit();
}

?>
